@@ -29,6 +29,7 @@ from ie_modal import *
 from ie_action import *
 from ie_slots import SLOT_QUIVER
 from ie_restype import RES_2DA
+from GameCheck import PARTY_SIZE
 import GameCheck
 import GUICommon
 import CommonTables
@@ -60,9 +61,12 @@ CurrentWindow = None
 DraggedPortrait = None
 ActionBarControlOffset = 0
 ReturnToGame = None
+ScreenHeight = GemRB.GetSystemVariable (SV_HEIGHT)
+PortraitButtons = None
 
 #The following tables deal with the different control indexes and string refs of each game
 #so that actual interface code can be game neutral
+AITip = {"Deactivate" : 15918, "Enable" : 15917}
 if GameCheck.IsPST(): #Torment
 	import GUIClasses
 	TimeWindow = None
@@ -88,12 +92,11 @@ elif GameCheck.IsIWD2(): #Icewind Dale 2
 	}
 	OptionControl = {
 	'Inventory' : 5, 'Map' : 7, 'Mage': 5, 'Priest': 6, 'Stats': 8, 'Journal': 6,
-	'Options' : 9, 'Rest': 12, 'Follow': 0, 'Expand': 10, 'AI': 6,
+	'Options' : 9, 'Rest': 12, 'Follow': 0, 'Expand': 10, 'AI': 14,
 	'Game': 0, 'Party' : 13,  'Time': 10, #not in pst
 	'SpellBook': 4, 'SelectAll': 11
 	}
 else: # Baldurs Gate, Icewind Dale
-	AITip = {"Deactivate" : 15918, "Enable" : 15917}
 	OptionTip = {
 	'Inventory' : 16307, 'Map': 16310, 'Mage': 16309, 'Priest': 14930, 'Stats': 16306, 'Journal': 16308,
 	'Options' : 16311, 'Rest': 11942, 'Follow': 41647,  'Expand': 41660, 'AI' : 1, 'Game' : 16313, 'Party' : 16312
@@ -139,12 +142,15 @@ def SetupMenuWindowControls (Window, Gears=None, CloseWindowCallback=None):
 
 	if iwd2: # IWD2 has one spellbook to rule them all
 		ActionBarControlOffset = 6 #portrait and action window were merged
-		# Spellbook
-		Button = InitOptionButton(Window, 'SpellBook', GUISPL.OpenSpellBookWindow)
-		if Gears: # todo: don't know if it needs this if or if it's if'fing around
-			# Select All
-			Button = InitOptionButton(Window, 'SelectAll', GUICommon.SelectAllOnPress)
 
+		Button = InitOptionButton(Window, 'SpellBook', GUISPL.OpenSpellBookWindow)
+
+		# AI
+		Button = InitOptionButton(Window, 'AI', AIPress)
+		AIPress (0) #this initialises the state and tooltip
+
+		# Select All
+		Button = InitOptionButton(Window, 'SelectAll', GUICommon.SelectAllOnPress)
 	elif pst: #pst has these three controls here instead of portrait pane
 		# (Un)Lock view on character
 		Button = InitOptionButton(Window, 'Follow', OnLockViewPress)  # or 41648 Unlock ...
@@ -232,11 +238,11 @@ def SetupMenuWindowControls (Window, Gears=None, CloseWindowCallback=None):
 		# Pendulum, gears, sun/moon dial (time)
 		# FIXME: display all animations: CPEN, CGEAR, CDIAL
 		if how: # how doesn't have this in the right place
-			pos = GemRB.GetSystemVariable (SV_HEIGHT)-71
+			pos = ScreenHeight - 71
 			Window.CreateButton (OptionControl['Time'], 6, pos, 64, 71)
 		Button = Window.GetControl (OptionControl['Time'])
 		if bg2:
-			Label = Button.CreateLabelOnButton (0x10000009, "NORMAL", 0)
+			Label = Button.CreateLabelOnButton (0x10000009, "NORMAL", IE_FONT_SINGLE_LINE)
 			Label.SetAnimation ("CPEN")
 
 		Button.SetAnimation ("CGEAR")
@@ -329,7 +335,7 @@ def PortraitPress (): #not used in pst. TODO:make an enhancement option?
 def AIPress (toggle=1):
 	"""Toggles the party AI or refreshes the button state if toggle = 0"""
 
-	if GameCheck.IsPST():
+	if GameCheck.IsPST() or GameCheck.IsIWD2():
 		Button = OptionsWindow.GetControl (OptionControl['AI'])
 	else:
 		Button = PortraitWindow.GetControl (OptionControl['AI'])
@@ -435,7 +441,7 @@ def OpenActionsWindowControls (Window): #FIXME:unused in pst. one day could be?
 		return
 	# Gears (time) when options pane is down
 	Button = Window.GetControl (62)
-	Label = Button.CreateLabelOnButton (0x1000003e, "NORMAL", 0)
+	Label = Button.CreateLabelOnButton (0x1000003e, "NORMAL", IE_FONT_SINGLE_LINE)
 
 	# FIXME: display all animations
 	Label.SetAnimation ("CPEN")
@@ -1259,6 +1265,94 @@ def RunSelectionChangeHandler ():
 		SelectionChangeHandler ()
 	return
 
+# returns buttons and a numerical index
+# does nothing new in pst, iwd2 due to layout
+# in the rest, it will enable extra button generation for higher resolutions
+# Mode determines arrangment direction, horizontal being for party reform and potentially save/load
+def GetPortraitButtonPairs (Window, ExtraSlots=0, Mode="vertical"):
+	pairs = {}
+	oldSlotCount = 6 + ExtraSlots
+
+	for i in range(min(oldSlotCount, PARTY_SIZE)): # the default chu/game limit or less
+		pairs[i] = Window.GetControl (i)
+
+	# nothing left to do
+	PartySize = GemRB.GetPartySize ()
+	if PartySize <= oldSlotCount:
+		return pairs
+
+	if GameCheck.IsIWD2() or GameCheck.IsPST():
+		print "Parties larger than 6 are currently not supported in IWD2 and PST! Using 6 ..."
+		return pairs
+
+	# generate new buttons by copying from existing ones
+	firstButton = pairs[0]
+	firstRect = firstButton.GetRect ()
+	buttonHeight = firstRect["Height"]
+	buttonWidth = firstRect["Width"]
+	xOffset = firstRect["X"]
+	yOffset = firstRect["Y"]
+	windowRect = Window.GetRect()
+	windowHeight = windowRect["Height"]
+	windowWidth = windowRect["Width"]
+	limit = limitStep = 0
+	scale = 0
+	portraitGap = 0
+	if Mode ==  "horizontal":
+		xOffset += 3*buttonWidth  # width of other controls in party reform; we'll draw on the other side (atleast in guiw8, guiw10 has no need for this)
+		maxWidth = windowWidth - xOffset
+		limit = maxWidth
+		limitStep = buttonWidth
+	else:
+		# reduce it by existing slots + 0 slots in framed views (eg. inventory) and
+		# 1 in main game control (for spacing and any other controls below (ai/select all in bg2))
+		maxHeight = windowHeight - buttonHeight*6 - buttonHeight/2
+		#print "GetPortraitButtonPairs:", ScreenHeight, windowHeight, maxHeight
+		if windowHeight != ScreenHeight:
+			maxHeight += buttonHeight/2
+		limit = maxHeight
+		# for framed views, limited to 6, we downscale the buttons to fit, clipping their portraits
+		if maxHeight < buttonHeight:
+			unused = 20 # remaining unused space below the portraits
+			scale = 1
+			portraitGap = buttonHeight
+			buttonHeight = (buttonHeight*6 + unused) / PartySize
+			portraitGap = portraitGap - buttonHeight - 2 # 2 for a quasi border
+			limit = windowHeight - buttonHeight*6 + unused
+		limitStep = buttonHeight
+
+	for i in range(len(pairs), PartySize):
+		if limitStep > limit:
+			raise SystemExit, "Not enough window space for so many party members (portraits), bailing out! %d vs %d" %(limit, buttonHeight)
+		nextID = 1000 + i
+		if Window.HasControl (nextID):
+			pairs[i] = Window.GetControl (nextID)
+			continue
+		if Mode ==  "horizontal":
+			Window.CreateButton (nextID, xOffset+i*buttonWidth, yOffset, buttonWidth, buttonHeight)
+		else:
+			# vertical
+			Window.CreateButton (nextID, xOffset, i*buttonHeight+yOffset+i*2*scale, buttonWidth, buttonHeight)
+		button = Window.GetControl (nextID)
+		button.SetSprites ("GUIRSPOR", 0, 0, 1, 0, 0)
+
+		pairs[i] = button
+		limit -= limitStep
+
+	# move the buttons back up, to combine the freed space
+	if scale:
+		for i in range(oldSlotCount):
+			button = pairs[i]
+			button.SetSize (buttonWidth, buttonHeight)
+			if i == 0:
+				continue # don't move the first portrait
+			rect = button.GetRect ()
+			x = rect["X"]
+			y = rect["Y"]
+			button.SetPos (x, y-portraitGap*i)
+
+	return pairs
+
 #NOTE: this is for pst's hp buttons, but it could be optionally exported to other games
 portrait_hp_numeric = [0, 0, 0, 0, 0, 0]
 
@@ -1285,7 +1379,7 @@ def OpenPortraitWindow (needcontrols=0):
 		else:
 			if GameCheck.HasHOW():
 				# Rest (how)
-				pos = GemRB.GetSystemVariable (SV_HEIGHT) - 37
+				pos = ScreenHeight - 37
 				Window.CreateButton (8, 6, pos, 55, 37)
 				Button = Window.GetControl (8)
 				Button.SetSprites ("GUIRSBUT", 0,0,1,0,0)
@@ -1318,16 +1412,17 @@ def OpenPortraitWindow (needcontrols=0):
 			Button.SetTooltip (11942)
 			Button.SetEvent (IE_GUI_BUTTON_ON_PRESS, RestPress)
 
-	for i in range (PARTY_SIZE):
-		Button = Window.GetControl (i)
+	PortraitButtons = GetPortraitButtonPairs (Window)
+	for i in PortraitButtons:
+		Button = PortraitButtons[i]
 		if GameCheck.IsIWD1() or GameCheck.IsIWD2():
 			Button.SetFont ("STATES")
 			# label for status flags (dialog, store, level up)
-			Button.CreateLabelOnButton(200 + i, "STATES", IE_FONT_ALIGN_TOP | IE_FONT_ALIGN_RIGHT) #level up icon is on the right
+			Button.CreateLabelOnButton(200 + i, "STATES", IE_FONT_ALIGN_TOP | IE_FONT_ALIGN_CENTER | IE_FONT_SINGLE_LINE) #level up icon is on the right
 		elif not GameCheck.IsPST():
 			Button.SetFont ("STATES2")
 			# label for status flags (dialog, store, level up)
-			Button.CreateLabelOnButton(200 + i, "STATES2", IE_FONT_ALIGN_TOP | IE_FONT_ALIGN_RIGHT) #level up icon is on the right
+			Button.CreateLabelOnButton(200 + i, "STATES2", IE_FONT_ALIGN_TOP | IE_FONT_ALIGN_CENTER | IE_FONT_SINGLE_LINE) #level up icon is on the right
 
 		Button.SetVarAssoc ("PressedPortrait", i+1)
 
@@ -1347,7 +1442,7 @@ def OpenPortraitWindow (needcontrols=0):
 		if GameCheck.IsIWD1():
 			# overlay a label, so we can display the hp with the correct font. Regular button label
 			#   is used by effect icons
-			Button.CreateLabelOnButton(100+i, "NUMFONT", IE_FONT_ALIGN_TOP|IE_FONT_ALIGN_LEFT)
+			Button.CreateLabelOnButton(100+i, "NUMFONT", IE_FONT_ALIGN_TOP|IE_FONT_ALIGN_LEFT|IE_FONT_SINGLE_LINE)
 			HPLabel = Window.GetControl (100+i)
 			HPLabel.SetUseRGB (True)
 
@@ -1374,17 +1469,20 @@ def OpenPortraitWindow (needcontrols=0):
 def UpdatePortraitWindow ():
 	"""Updates all of the portraits."""
 
+	global PortraitButtons
+
 	Window = PortraitWindow
 
 	pc = GemRB.GameGetSelectedPCSingle ()
 	Inventory = GemRB.GetVar ("Inventory")
 
-	for portid in range (PARTY_SIZE):
+	PortraitButtons = GetPortraitButtonPairs (Window)
+	for portid in PortraitButtons:
 		if GameCheck.IsPST():
 			UpdateAnimatedPortrait(Window,portid)
 			continue
 
-		Button = Window.GetControl (portid)
+		Button = PortraitButtons[portid]
 		pic = GemRB.GetPlayerPortrait (portid+1, 1)
 		if Inventory and pc != portid+1:
 			pic = None
@@ -1415,7 +1513,7 @@ def UpdatePortraitWindow ():
 		ratio_str, color = GUICommon.SetupDamageInfo (portid+1, Button, Window)
 
 		# character - 1 == bam cycle
-		talk = store = flag = blank = ""
+		talk = store = flag = blank = ' '
 		if GameCheck.IsBG2():
 			# as far as I can tell only BG2 has icons for talk or store
 			flag = blank = chr(238)
@@ -1445,16 +1543,16 @@ def UpdatePortraitWindow ():
 		states = ""
 		# calculate the partial row
 		idx = numEffects % numCols
-		states = effects[0:idx] + "\n"
+		states = effects[0:idx]
 
 		for x in range(idx, numEffects): # now do any rows that are full
-			states = states + effects[x]
-			if (x - idx) % numCols == numCols - 1:
+			if (x - idx) % numCols == 0:
 				states = states + "\n"
+			states = states + effects[x]
 
 		FlagLabel = Window.GetControl(200 + portid)
 		if flag != blank:
-			FlagLabel.SetText(flag)
+			FlagLabel.SetText(flag.ljust(3, blank))
 		else:
 			FlagLabel.SetText("")
 		Button.SetText(states)
@@ -1582,6 +1680,7 @@ def PortraitButtonHPOnPress (): ##pst hitpoint display
 
 	portrait_hp_numeric[i-1] = not portrait_hp_numeric[i-1]
 	ButtonHP = Window.GetControl (5 + i)
+#	ButtonHP = Window.GetControl (PortraitButtons[i])
 
 	if portrait_hp_numeric[i-1]:
 		op = OP_NAND
@@ -1594,7 +1693,7 @@ def PortraitButtonHPOnPress (): ##pst hitpoint display
 def SelectionChanged ():
 	"""Ran by the Game class when a PC selection is changed."""
 
-	global PortraitWindow
+	global PortraitWindow, PortraitButtons
 
 	if not PortraitWindow:
 		return
@@ -1603,8 +1702,9 @@ def SelectionChanged ():
 	GemRB.SetVar ("ActionLevel", 0)
 	if (not SelectionChangeHandler):
 		UpdateActionsWindow ()
-		for i in range (PARTY_SIZE):
-			Button = PortraitWindow.GetControl (i)
+		PortraitButtons = GetPortraitButtonPairs (PortraitWindow)
+		for i in PortraitButtons:
+			Button = PortraitButtons[i]
 			Button.EnableBorder (FRAME_PC_SELECTED, GemRB.GameIsPCSelected (i + 1))
 		if SelectionChangeMultiHandler:
 			SelectionChangeMultiHandler ()
@@ -1618,8 +1718,9 @@ def SelectionChanged ():
 			MageTable = GemRB.LoadTable ("magesch")
 			GemRB.SetVar ("MAGESCHOOL", MageTable.FindValue (3, CommonTables.KitList.GetValue (Kit, 6) ) )
 
-		for i in range (PARTY_SIZE):
-			Button = PortraitWindow.GetControl (i)
+		PortraitButtons = GetPortraitButtonPairs (PortraitWindow)
+		for i in PortraitButtons:
+			Button = PortraitButtons[i]
 			Button.EnableBorder (FRAME_PC_SELECTED, i + 1 == sel)
 	import CommonWindow
 	CommonWindow.CloseContainerWindow()
@@ -1649,7 +1750,7 @@ def PortraitButtonOnMouseEnter ():
 		return
 
 	if GemRB.IsDraggingItem ():
-		Button = PortraitWindow.GetControl (i-1)
+		Button = PortraitButtons[i-1]
 		Button.EnableBorder (FRAME_PC_TARGET, 1)
 	return
 
@@ -1677,7 +1778,7 @@ def PortraitButtonOnMouseLeave ():
 	if not i:
 		return
 
-	Button = PortraitWindow.GetControl (i-1)
+	Button = PortraitButtons[i-1]
 	Button.EnableBorder (FRAME_PC_TARGET, 0)
 	GemRB.SetVar ("PressedPortrait", 0)
 	GemRB.SetTimedEvent (CheckDragging, 1)
