@@ -89,7 +89,6 @@ def CloseOptionsWindow ():
 		GUICommonWindows.PortraitWindow = OldPortraitWindow
 		OldPortraitWindow = None
 
-	GemRB.GamePause (0, 3)
 	return
 
 ###################################################
@@ -357,7 +356,7 @@ def OpenGameplayOptionsWindow ():
 	GUIOPTControls.OptDone (CloseGameplayOptionsWindow, Window, 7)
 	GUIOPTControls.OptCancel (CloseGameplayOptionsWindow, Window, 20)
 
-	GUIOPTControls.OptSlider (18042, 18017, HelpTextArea, Window, 1, 21, 17143, 'Tooltips', DisplayHelpTooltipDelay, TOOLTIP_DELAY_FACTOR)
+	GUIOPTControls.OptSlider (18042, 18017, HelpTextArea, Window, 1, 21, 17143, 'Tooltips', DisplayHelpTooltipDelay, 10)
 	GUIOPTControls.OptSlider (18042, 18018, HelpTextArea, Window, 2, 22, 17144, 'Mouse Scroll Speed', DisplayHelpMouseScrollingSpeed, 5)
 	GUIOPTControls.OptSlider (18042, 18019, HelpTextArea, Window, 3, 23, 17145, 'Keyboard Scroll Speed', None, 5)
 	GUIOPTControls.OptSlider (18042, 18020, HelpTextArea, Window, 12, 24, 13911, 'Difficulty Level', None, 0)
@@ -382,7 +381,7 @@ def OpenGameplayOptionsWindow ():
 
 def DisplayHelpTooltipDelay ():
 	HelpTextArea.SetText (18017)
-	GemRB.SetTooltipDelay (GemRB.GetVar ("Tooltips") )
+	GemRB.SetTooltipDelay (GemRB.GetVar ("Tooltips") * TOOLTIP_DELAY_FACTOR/10)
 
 def DisplayHelpMouseScrollingSpeed ():
 	HelpTextArea.SetText (18018)
@@ -510,18 +509,11 @@ def OpenMovieWindow ():
 	#reloading the guiopt windowpack
 	GemRB.LoadWindowPack ("GUIOPT", 800, 600)
 	TextAreaControl = Window.GetControl(0)
-	TextAreaControl.SetFlags(IE_GUI_TEXTAREA_SELECTABLE)
 	PlayButton = Window.GetControl(2)
 	CreditsButton = Window.GetControl(3)
 	DoneButton = Window.GetControl(4)
 	MoviesTable = GemRB.LoadTable("MOVIDESC")
-	for i in range(0, MoviesTable.GetRowCount() ):
-		t = MoviesTable.GetRowName(i)
-		#temporarily out too (see above)
-		#if GemRB.GetVar(t)==1:
-		if 1==1:
-			s = MoviesTable.GetValue(i, 0)
-			TextAreaControl.Append(s,-1)
+	TextAreaControl.SetOptions([MoviesTable.GetValue(i, 0) for i in range(0, MoviesTable.GetRowCount())])
 	TextAreaControl.SetVarAssoc("MovieIndex",0)
 	PlayButton.SetText(17318)
 	CreditsButton.SetText(15591)
