@@ -118,6 +118,7 @@ def LoadSingle():
 	if QuitWindow:
 		QuitWindow.Unload()
 	GemRB.SetVar("PlayMode",0)
+	GemRB.SetVar("SaveDir",0)
 	GemRB.SetNextScript("GUILOAD")
 	return
 
@@ -126,7 +127,8 @@ def MissionPack():
 		StartWindow.Unload()
 	if QuitWindow:
 		QuitWindow.Unload()
-	GemRB.SetVar("PlayMode",3) #use mpsave for saved games
+	GemRB.SetVar("PlayMode",1)
+	GemRB.SetVar("SaveDir",1) #use mpsave for saved games
 	GemRB.SetNextScript("GUILOAD")
 	return
 
