@@ -18,21 +18,20 @@
 #
 #character generation (GUICG 0)
 import GemRB
-from CharGenCommon import *
-
-CharGenWindow = 0
+import CharGenCommon
+import GUICommonWindows
 
 def OnLoad():
-	global CharGenWindow
-
 	GemRB.SetVar("Gender",0) #gender
 	GemRB.SetVar("Race",0) #race
 	GemRB.SetVar("Class",0) #class
 	GemRB.SetVar("Class Kit",0) #class
 	GemRB.SetVar("Alignment",-1) #alignment
 
+	GUICommonWindows.PortraitWindow = None
+
 	MyChar = GemRB.GetVar ("Slot")
-	GemRB.CreatePlayer ("charbase", MyChar | 0x8000 )
-	DisplayOverview (1)	
+	GemRB.CreatePlayer ("charbase", MyChar | 0x8000, 0, 11 ) # 11 = force bg2
+	CharGenCommon.DisplayOverview (1)
 
 	return
