@@ -33,8 +33,7 @@ def OnLoad():
 	TextAreaControl.SetText (10962)
 
 	TextAreaControl = ImportWindow.GetControl (2)
-	TextAreaControl.SetFlags (IE_GUI_TEXTAREA_SELECTABLE)
-	TextAreaControl.GetCharacters ()
+	TextAreaControl.ListResources (CHR_EXPORTS)
  
 	DoneButton = ImportWindow.GetControl (0)
 	DoneButton.SetText (2610)
