@@ -18,6 +18,7 @@
 #
 #character generation, multi-class (GUICG10)
 import GemRB
+import GUICommon
 import CommonTables
 from ie_stats import *
 from GUIDefines import *
@@ -27,9 +28,11 @@ ClassWindow = 0
 TextAreaControl = 0
 DoneButton = 0
 MyChar = 0
+ButtonCount = 0
+MCRowIndices = []
 
 def OnLoad():
-	global ClassWindow, TextAreaControl, DoneButton, MyChar
+	global ClassWindow, TextAreaControl, DoneButton, MyChar, ButtonCount, MCRowIndices
 	
 	GemRB.LoadWindowPack("GUICG", 640, 480)
 	ClassWindow = GemRB.LoadWindow(10)
@@ -39,36 +42,31 @@ def OnLoad():
 	Race = GemRB.GetPlayerStat (MyChar, IE_RACE)
 	RaceName = CommonTables.Races.GetRowName(CommonTables.Races.FindValue (3, Race) )
 
-	j=0
-	for i in range(1,ClassCount):
-		if CommonTables.Classes.GetValue(i-1,4)==0:
-			continue
-		if j>11:
-			Button = ClassWindow.GetControl(j+7)
-		else:
-			Button = ClassWindow.GetControl(j+2)
-		Button.SetState(IE_GUI_BUTTON_DISABLED)
-		Button.SetFlags(IE_GUI_BUTTON_RADIOBUTTON,OP_OR)
-		j = j + 1
-	j=0
+	MCRowIndices = []
 	for i in range(1,ClassCount):
 		ClassName = CommonTables.Classes.GetRowName(i-1)
 		Allowed = CommonTables.Classes.GetValue(ClassName, RaceName)
-		if CommonTables.Classes.GetValue(i-1,4)==0:
+		if CommonTables.Classes.GetValue (ClassName, "MULTI") == 0:
+			# not a multiclass
 			continue
-		if j>11:
-			Button = ClassWindow.GetControl(j+7)
-		else:
-			Button = ClassWindow.GetControl(j+2)
+		MCRowIndices.append((i-1, Allowed))
 
-		t = CommonTables.Classes.GetValue(i-1, 0)
-		Button.SetText(t )
-		j=j+1
-		if Allowed ==0:
-			continue
-		Button.SetState(IE_GUI_BUTTON_ENABLED)
-		Button.SetEvent(IE_GUI_BUTTON_ON_PRESS, ClassPress)
-		Button.SetVarAssoc("Class", i) #multiclass, actually
+	ButtonCount = 10
+	if len(MCRowIndices) > 10:
+		# add another button, there's another slot left
+		ClassWindow.CreateButton (15, 18, 250, 271, 20)
+		extramc = ClassWindow.GetControl(15)
+		extramc.SetState(IE_GUI_BUTTON_DISABLED)
+		extramc.SetFlags(IE_GUI_BUTTON_RADIOBUTTON, OP_OR)
+		extramc.SetSprites("GUICGBC",0, 0,1,2,3)
+		ButtonCount = 11
+	if len(MCRowIndices) > 11:
+		# bah, also add a scrollbar
+		ClassWindow.CreateScrollBar(1000, 290, 50, 16, 220, "GUISCRCW")
+		ScrollBar = ClassWindow.GetControl (1000)
+		ScrollBar.SetVarAssoc("TopIndex", len(MCRowIndices)-10)
+		ScrollBar.SetEvent(IE_GUI_SCROLLBAR_ON_CHANGE, RedrawMCs)
+		ScrollBar.SetDefaultScrollBar()
 
 	BackButton = ClassWindow.GetControl(14)
 	BackButton.SetText(15416)
@@ -83,13 +81,14 @@ def OnLoad():
 	DoneButton.SetEvent(IE_GUI_BUTTON_ON_PRESS, NextPress)
 	BackButton.SetEvent(IE_GUI_BUTTON_ON_PRESS, BackPress)
 	DoneButton.SetState(IE_GUI_BUTTON_DISABLED)
+	RedrawMCs()
 	ClassWindow.SetVisible(WINDOW_VISIBLE)
 	return
 
 def ClassPress():
 	GUICG2.SetClass()
-	Class = GemRB.GetVar("Class")-1
-	TextAreaControl.SetText(CommonTables.Classes.GetValue(Class,1) )
+	ClassName = GUICommon.GetClassRowName (GemRB.GetVar ("Class")-1, "index")
+	TextAreaControl.SetText (CommonTables.Classes.GetValue (ClassName, "DESC_REF"))
 	DoneButton.SetState(IE_GUI_BUTTON_ENABLED)
 	return
 
@@ -106,11 +105,29 @@ def NextPress():
 		ClassWindow.Unload()
 
 	# find the class from the class table
-	ClassIndex = GemRB.GetVar ("Class") - 1
-	Class = CommonTables.Classes.GetValue (ClassIndex, 5)
-	#protect against barbarians
-	ClassName = CommonTables.Classes.GetRowName (CommonTables.Classes.FindValue (5, Class) )
+	ClassName = GUICommon.GetClassRowName (GemRB.GetVar ("Class")-1, "index")
+	Class = CommonTables.Classes.GetValue (ClassName, "ID")
 	GemRB.SetPlayerStat (MyChar, IE_CLASS, Class)
 
 	GemRB.SetNextScript("CharGen4") #alignment
 	return
+
+#TODO: deal with the potential scrollbar
+def RedrawMCs():
+	for i in range (2, 2+ButtonCount): # loop over the available buttons
+		if i == 12:
+			Button = ClassWindow.GetControl(15) # the extra button
+		else:
+			Button = ClassWindow.GetControl(i)
+		Button.SetState(IE_GUI_BUTTON_ENABLED)
+		Button.SetFlags(IE_GUI_BUTTON_RADIOBUTTON, OP_OR)
+
+		t = GUICommon.GetClassRowName (MCRowIndices[i-2][0], "index")
+		t = CommonTables.Classes.GetValue(t, "NAME_REF")
+		Button.SetText(t )
+		if not MCRowIndices[i-2][1]:
+			Button.SetState(IE_GUI_BUTTON_DISABLED)
+			continue
+		Button.SetState(IE_GUI_BUTTON_ENABLED)
+		Button.SetEvent(IE_GUI_BUTTON_ON_PRESS, ClassPress)
+		Button.SetVarAssoc("Class", MCRowIndices[i-2][0]+1) #multiclass, actually; just a wierd system
