@@ -35,14 +35,10 @@ def OnLoad():
 	CreditsButton = MovieWindow.GetControl (3)
 	DoneButton = MovieWindow.GetControl (4)
 	MoviesTable = GemRB.LoadTable ("MOVIDESC")
-	for i in range( MoviesTable.GetRowCount () ):
-		t = MoviesTable.GetRowName (i)
-		if GemRB.GetVar (t)==1:
-			s = MoviesTable.GetValue (i, 0)
-			TextAreaControl.Append (s,-1)
+	opts = [MoviesTable.GetValue (i, 0) for i in range( MoviesTable.GetRowCount () ) if GemRB.GetVar (MoviesTable.GetRowName (i))==1]
+	TextAreaControl.SetOptions(opts)
 	TextAreaControl.SetVarAssoc ("MovieIndex",0)
-	TextAreaControl.SetFlags (IE_GUI_TEXTAREA_SELECTABLE, OP_NAND)
-	TextAreaControl.SetEvent (IE_GUI_TEXTAREA_ON_CHANGE, MoviePress)
+	TextAreaControl.SetEvent (IE_GUI_TEXTAREA_ON_SELECT, MoviePress)
 	PlayButton.SetText (17318)
 	CreditsButton.SetText (15591)
 	DoneButton.SetText (11973)
@@ -55,7 +51,6 @@ def OnLoad():
 
 def MoviePress():
 	PlayButton.SetStatus (IE_GUI_BUTTON_ENABLED)
-	TextAreaControl.SetFlags (IE_GUI_TEXTAREA_SELECTABLE,OP_SET) # show selection
 	return
 
 def PlayPress():
@@ -65,7 +60,6 @@ def PlayPress():
 		if GemRB.GetVar (t)==1:
 			if s==0:
 				PlayButton.SetStatus (IE_GUI_BUTTON_DISABLED)
-				TextAreaControl.SetFlags (IE_GUI_TEXTAREA_SELECTABLE,OP_NAND) # hide selection
 				s = MoviesTable.GetRowName (i)
 				GemRB.PlayMovie (s, 1)
 				MovieWindow.Invalidate ()
