@@ -43,6 +43,7 @@ CHARMEDPC     = 254
 ENEMY         = 255
 
 # state bits (IE_STATE)
+STATE_BERSERK = 2
 STATE_PANIC = 4
 STATE_HELPLESS = 1 + 32
 STATE_PETRIFIED = 8 + 64 + 128
@@ -63,7 +64,7 @@ MC_EXPORTABLE = 0x800
 
 MC_PLOT_CRITICAL = 0x2000
 MC_BEENINPARTY = 0x8000
-MC_HIDDEN = 0x10000
+MC_SEENPARTY = 0x10000
 
 # stats
 IE_HITPOINTS 			= 0
@@ -322,7 +323,7 @@ IE_HAIR_COLOR			= 214
 IE_MC_FLAGS			= 215
 IE_CLASSLEVELSUM		= 216
 IE_ALIGNMENT			= 217
-IE_UNSELECTABLE			= 218
+IE_CASTING			= 218
 IE_ARMOR_TYPE			= 219
 IE_TEAM				= 220
 IE_FACTION			= 221
@@ -352,7 +353,7 @@ IE_LEVELDRUID                   = 243
 IE_LEVELMONK                    = 244
 IE_LEVELPALADIN                 = 245
 IE_LEVELRANGER                  = 246
-IE_LEVELSORCEROR                = 247
+IE_LEVELSORCERER                = 247
 #248 IE_LEVELCLASS12
 #249 IE_LEVELCLASS13
 #the remaining six stats are spell states
