@@ -176,7 +176,8 @@ def BackPress():
 	GemRB.SetNextScript("CharGen3")
 	GemRB.SetVar("Class",0)  #scrapping the class value
 	MyChar = GemRB.GetVar("Slot")
-	GemRB.SetPlayerStat (IE_CLASS, 0)
+	GemRB.SetPlayerStat (MyChar, IE_CLASS, 0)
+	GemRB.SetPlayerStat (MyChar, IE_KIT, 0)
 	return
 
 def NextPress():
