@@ -37,6 +37,12 @@ OptionsWindow = None
 OldPortraitWindow = None
 OldOptionsWindow = None
 
+def OpenInventoryWindowClick ():
+	tmp = GemRB.GetVar ("PressedPortrait")
+	GemRB.GameSelectPC (tmp, True, SELECT_REPLACE)
+	OpenInventoryWindow ()
+	return
+
 def OpenInventoryWindow ():
 	global InventoryWindow, OptionsWindow, PortraitWindow
 	global OldPortraitWindow, OldOptionsWindow
@@ -147,7 +153,7 @@ def OpenInventoryWindow ():
 	Label = Window.GetControl (0x1000003a)
 	Label.SetTooltip (17378)
 
-	#info label, game paused, etc
+	# info label, game paused, etc
 	Label = Window.GetControl (0x1000003f)
 	Label.SetText ("")
 
@@ -160,15 +166,28 @@ def OpenInventoryWindow ():
 			Button.SetEvent (IE_GUI_MOUSE_LEAVE_BUTTON, InventoryCommon.MouseLeaveSlot)
 			Button.SetVarAssoc ("ItemButton", slot+1)
 			Button.SetFont ("NUMFONT")
-			Button.SetFlags (IE_GUI_BUTTON_ALIGN_RIGHT | IE_GUI_BUTTON_ALIGN_BOTTOM | IE_GUI_BUTTON_PICTURE, OP_OR)
 
 	GemRB.SetVar ("TopIndex", 0)
+	
+	for i in range (4):
+		Button = Window.GetControl (109+i)
+		Button.SetEvent (IE_GUI_BUTTON_ON_PRESS, ChangeWeaponPressed)
+		Button.SetVarAssoc("Equipped", i)
+		Button.SetFlags (IE_GUI_BUTTON_RADIOBUTTON, OP_OR)
+		#Why they mess up .chu's i don't know
+		Button.SetSprites("INVBUT3", i, 0, 1, 2, 3)
 
 	GUICommonWindows.SetSelectionChangeHandler (UpdateInventoryWindow)
 
 	UpdateInventoryWindow ()
 	return
 
+def ChangeWeaponPressed ():
+	pc = GemRB.GameGetSelectedPCSingle ()
+	Equipped = GemRB.GetVar ("Equipped")
+	GemRB.SetEquippedQuickSlot (pc, Equipped, -1)
+	return
+
 #complete update
 def UpdateInventoryWindow ():
 	Window = InventoryWindow
@@ -180,6 +199,11 @@ def UpdateInventoryWindow ():
 	if Count<1:
 		Count=1
 	ScrollBar.SetVarAssoc ("TopIndex", Count)
+	Equipped = GemRB.GetEquippedQuickSlot (pc, 1)
+	GemRB.SetVar ("Equipped", Equipped)
+	for i in range (4):
+		Button = Window.GetControl (109+i)
+		Button.SetVarAssoc("Equipped", i)
 	RefreshInventoryWindow ()
 	# populate inventory slot controls
 	SlotCount = GemRB.GetSlotType (-1)["Count"]
@@ -262,7 +286,7 @@ def RefreshInventoryWindow ():
 			Button = Window.GetControl (i+76)
 
 		if GemRB.IsDraggingItem ()==1:
-			Button.SetState (IE_GUI_BUTTON_SECOND)
+			Button.SetState (IE_GUI_BUTTON_FAKEPRESSED)
 		else:
 			Button.SetState (IE_GUI_BUTTON_ENABLED)
 		Button.SetEvent (IE_GUI_BUTTON_ON_DRAG_DROP, InventoryCommon.OnDragItemGround)
@@ -280,11 +304,7 @@ def RefreshInventoryWindow ():
 		GUICommon.UpdateInventorySlot (pc, Button, Slot, "ground")
 
 	#if actor is uncontrollable, make this grayed
-	held = GemRB.GetPlayerStat (pc, IE_HELD) + GemRB.GetPlayerStat (pc, IE_CASTERHOLD)
-	if held or GemRB.GetPlayerStat (pc, IE_STATE_ID) & STATE_DEAD:
-		Window.SetVisible (WINDOW_GRAYED)
-	else:
-		Window.SetVisible (WINDOW_VISIBLE)
+	GUICommon.AdjustWindowVisibility (Window, pc, False)
 	PortraitWindow.SetVisible (WINDOW_VISIBLE)
 	OptionsWindow.SetVisible (WINDOW_VISIBLE)
 	return
