@@ -45,7 +45,7 @@ def OnLoad():
 	JoinGameButton = StartWindow.GetControl(0x0B)
 	OptionsButton = StartWindow.GetControl(0x08)
 	QuitGameButton = StartWindow.GetControl(0x01)
-	StartWindow.CreateLabel(0x0fff0000, 0,0,800,30, "REALMS2", "", 1)
+	StartWindow.CreateLabel(0x0fff0000, 0,0,800,30, "REALMS2", "", IE_FONT_SINGLE_LINE | IE_FONT_ALIGN_CENTER)
 	VersionLabel = StartWindow.GetControl(0x0fff0000)
 	VersionLabel.SetText(GEMRB_VERSION)
 	ProtocolButton.SetStatus(IE_GUI_BUTTON_ENABLED)
