@@ -255,7 +255,7 @@ def UpdateRecordsWindow ():
 
 	# sex
 	GenderTable = GemRB.LoadTable ("GENDERS")
-	text = GenderTable.GetValue (GemRB.GetPlayerStat (pc, IE_SEX) - 1, 0)
+	text = GenderTable.GetValue (GemRB.GetPlayerStat (pc, IE_SEX) - 1, GTV_STR)
 	
 	Label = Window.GetControl (0x10000015)
 	Label.SetText (text)
@@ -273,7 +273,7 @@ def UpdateRecordsWindow ():
 	sym = ss.GetValue (align)
 
 	AlignmentTable = GemRB.LoadTable ("ALIGNS")
-	alignment_help = GemRB.GetString (AlignmentTable.GetValue (sym, 'DESC_REF'))
+	alignment_help = AlignmentTable.GetValue (sym, 'DESC_REF', GTV_REF)
 	frame = (3 * int (align / 16) + align % 16) - 4
 	
 	Button = Window.GetControl (5)
@@ -286,7 +286,7 @@ def UpdateRecordsWindow ():
 	# faction
 	faction = GemRB.GetPlayerStat (pc, IE_FACTION)
 	FactionTable = GemRB.LoadTable ("FACTIONS")
-	faction_help = GemRB.GetString (FactionTable.GetValue (faction, 0))
+	faction_help = FactionTable.GetValue (faction, 0, GTV_REF)
 	frame = FactionTable.GetValue (faction, 1)
 	
 	Button = Window.GetControl (6)
@@ -469,7 +469,7 @@ def GetCharacterHeader (pc):
 			avatar_header['SecoNextLevXP'] = GetNextLevelExp (avatar_header['SecoLevel'], avatar_header['SecoClass'])
 
 			# Converting to the displayable format
-			avatar_header['SecoClass'] = GemRB.GetString (CommonTables.Classes.GetValue (avatar_header['SecoClass'], "NAME_REF"))
+			avatar_header['SecoClass'] = CommonTables.Classes.GetValue (avatar_header['SecoClass'], "NAME_REF", GTV_REF)
 		else:
 			avatar_header['SecoLevel'] = 0
 			avatar_header['PrimClass'] = CommonTables.Classes.GetRowName (Class)
@@ -478,7 +478,7 @@ def GetCharacterHeader (pc):
 			avatar_header['SecoNextLevXP'] = 0
 
 	# Converting to the displayable format
-	avatar_header['PrimClass'] = GemRB.GetString (CommonTables.Classes.GetValue (avatar_header['PrimClass'], "NAME_REF"))
+	avatar_header['PrimClass'] = CommonTables.Classes.GetValue (avatar_header['PrimClass'], "NAME_REF", GTV_REF)
 
 
 
@@ -527,7 +527,7 @@ def GetStatOverview (pc):
 	stats.append (None)
 	StatesTable = GemRB.LoadTable ("states")
 	StateID = GS (IE_STATE_ID)
-	State = GemRB.GetString (StatesTable.GetValue (str (StateID), "NAME_REF"))
+	State = StatesTable.GetValue (str (StateID), "NAME_REF", GTV_REF)
 	stats.append ((won + GemRB.GetString (59856) + woff, "", 'd'))
 	stats.append ((State, "", 'd'))
 	stats.append (None)
