@@ -116,6 +116,7 @@ struct Effect {
 	ieDword Parameter4;
 	ieDword Parameter5;
 	ieDword Parameter6;
+	ieDword SourceX, SourceY;
 	ieDword PosX, PosY;
 	ieDword SourceType; //1-item, 2-spell
 	ieResRef Source;
@@ -140,6 +141,12 @@ public:
 			PosY=p.y;
 		}
 	}
+	void SetSourcePosition(const Point &p) {
+		if(SourceX==0xffffffff && SourceY==0xffffffff) {
+			SourceX=p.x;
+			SourceY=p.y;
+		}
+	}
 };
 
 }
