@@ -27,6 +27,8 @@
 #include "AnimationFactory.h"
 #include "FactoryObject.h"
 
+namespace GemRB {
+
 class GEM_EXPORT Factory {
 private:
 	std::vector< FactoryObject*> fobjects;
@@ -39,4 +41,6 @@ public:
 	void FreeObjects(void);
 };
 
+}
+
 #endif
