@@ -26,40 +26,28 @@
 #include "Interface.h"
 #include "Palette.h"
 #include "ScriptEngine.h"
-#include "Video.h"
+#include "Sprite2D.h"
 #include "GUI/EventMgr.h"
+#include "GUI/TextSystem/Font.h"
 
 namespace GemRB {
 
 Console::Console(const Region& frame)
-	: Control(frame)
+	: Control(frame), History(5)
 {
 	Cursor = NULL;
 	Back = NULL;
 	max = 128;
-	Buffer = ( unsigned char * ) malloc( max );
-	Buffer[0] = 0;
-	for(size_t i=0;i<HISTORY_SIZE;i++) {
-		History[i] = ( unsigned char * ) malloc( max );
-		History[i][0] = 0;
-	}
+	Buffer.reserve(max);
 	CurPos = 0;
 	HistPos = 0;
-	HistMax = 0;
-	palette = NULL;
-	font = NULL;
+	palette = new Palette( ColorWhite, ColorBlack );
 }
 
 Console::~Console(void)
 {
-	free( Buffer );
-	for (size_t i=0;i<HISTORY_SIZE;i++) {
-		free( History[i] );
-	}
-	Video *video = core->GetVideoDriver();
-
-	gamedata->FreePalette( palette );
-	video->FreeSprite( Cursor );
+	palette->release();
+	Sprite2D::FreeSprite( Cursor );
 }
 
 /** Draws the Console on the Output Display */
@@ -68,19 +56,23 @@ void Console::DrawInternal(Region& drawFrame)
 	if (Back) {
 		core->GetVideoDriver()->BlitSprite( Back, 0, drawFrame.y, true );
 	}
+	Font* font = core->GetTextFont();
 
-	core->GetVideoDriver()->DrawRect( drawFrame, ColorBlack );
-	font->Print( drawFrame, Buffer, palette,
-			IE_FONT_ALIGN_LEFT | IE_FONT_ALIGN_MIDDLE, true, NULL,
-			Cursor, CurPos, true );
-}
-/** Set Font */
-void Console::SetFont(Font* f)
-{
-	if (f != NULL) {
-		font = f;
+	Video* video = core->GetVideoDriver();
+	video->DrawRect( drawFrame, ColorBlack );
+	ieWord w = font->StringSize(Buffer.substr(0, CurPos)).w;
+	if (w + Cursor->Width > drawFrame.w) {
+		// shift left so the cursor remains visible
+		int shift = (w + Cursor->Width) - drawFrame.w;
+		drawFrame.x -= shift;
+		drawFrame.w += shift;
 	}
+	font->Print( drawFrame, Buffer, palette, IE_FONT_ALIGN_LEFT | IE_FONT_ALIGN_MIDDLE | IE_FONT_SINGLE_LINE);
+
+	ieWord vcenter = (drawFrame.h / 2) + (Cursor->Height / 2);
+	video->BlitSprite(Cursor, w + drawFrame.x, vcenter + drawFrame.y, true);
 }
+
 /** Set Cursor */
 void Console::SetCursor(Sprite2D* cur)
 {
@@ -95,21 +87,16 @@ void Console::SetBackGround(Sprite2D* back)
 	Back = back;
 }
 /** Sets the Text of the current control */
-void Console::SetText(const char* string)
+void Console::SetText(const String& string)
 {
-	strlcpy( ( char * ) Buffer, string, max );
+	Buffer = string;
 }
 /** Key Press Event */
 bool Console::OnKeyPress(unsigned char Key, unsigned short /*Mod*/)
 {
 	if (Key >= 0x20) {
-		size_t len = strlen( ( char* ) Buffer );
-		if (len + 1 < max) {
-			for (size_t i = len; i > CurPos; i--) {
-				Buffer[i] = Buffer[i - 1];
-			}
-			Buffer[CurPos++] = Key;
-			Buffer[len + 1] = 0;
+		if (Buffer.length() < max) {
+			Buffer.insert(CurPos++, 1, Key);
 		}
 		return true;
 	}
@@ -118,24 +105,17 @@ bool Console::OnKeyPress(unsigned char Key, unsigned short /*Mod*/)
 /** Special Key Press */
 bool Console::OnSpecialKeyPress(unsigned char Key)
 {
-	size_t len;
-
 	switch (Key) {
 		case GEM_BACKSP:
 			if (CurPos != 0) {
-				size_t len = strlen( ( const char * ) Buffer );
-				for (size_t i = CurPos; i < len; i++) {
-					Buffer[i - 1] = Buffer[i];
-				}
-				Buffer[len - 1] = 0;
-				CurPos--;
+				Buffer.erase(--CurPos, 1);
 			}
 			break;
 		case GEM_HOME:
 			CurPos = 0;
 			break;
 		case GEM_END:
-			CurPos = (unsigned short) strlen( (const char * ) Buffer);
+			CurPos = Buffer.length();
 			break;
 		case GEM_UP:
 			HistoryBack();
@@ -148,23 +128,22 @@ bool Console::OnSpecialKeyPress(unsigned char Key)
 				CurPos--;
 			break;
 		case GEM_RIGHT:
-			len = strlen( ( const char * ) Buffer );
-			if (CurPos < len) {
+			if (CurPos < Buffer.length()) {
 				CurPos++;
 			}
 			break;
 		case GEM_DELETE:
-			len = strlen( ( const char * ) Buffer );
-			if (CurPos < len) {
-				for (size_t i = CurPos; i < len; i++) {
-					Buffer[i] = Buffer[i + 1];
-				}
+			if (CurPos < Buffer.length()) {
+				Buffer.erase(CurPos, 1);
 			}
 			break;			
 		case GEM_RETURN:
-			core->GetGUIScriptEngine()->ExecString( ( char* ) Buffer );
-			HistoryAdd(false);
-			Buffer[0] = 0;
+			char* cBuf = MBCStringFromString(Buffer);
+			// FIXME: should prepend "# coding=<encoding name>" as per http://www.python.org/dev/peps/pep-0263/
+			core->GetGUIScriptEngine()->ExecString(cBuf, true);
+			free(cBuf);
+			HistoryAdd();
+			Buffer.erase();
 			CurPos = 0;
 			HistPos = 0;
 			break;
@@ -172,49 +151,34 @@ bool Console::OnSpecialKeyPress(unsigned char Key)
 	return true;
 }
 
-//ctrl-up
 void Console::HistoryBack()
 {
-	HistoryAdd(false);
-	if (HistPos < HistMax-1 && Buffer[0]) {
+	if (Buffer[0] && HistPos == 0 && History.Retrieve(HistPos) != Buffer) {
+		HistoryAdd();
 		HistPos++;
 	}
-	memcpy(Buffer, History[HistPos], max);
-	CurPos = (unsigned short) strlen ((const char *) Buffer);
+	Buffer = History.Retrieve(HistPos);
+	CurPos = Buffer.length();
+	if (++HistPos >= (int)History.Size()) {
+		HistPos--;
+	}
 }
 
-//ctrl-down
 void Console::HistoryForward()
 {
-	HistoryAdd(false);
-	if (HistPos == 0) {
-		Buffer[0]=0;
-		CurPos=0;
-		return;
+	if (--HistPos < 0) {
+		Buffer.erase();
+		HistPos++;
+	} else {
+		Buffer = History.Retrieve(HistPos);
 	}
-	HistPos--;
-	memcpy(Buffer, History[HistPos], max);
-	CurPos = (unsigned short) strlen ((const char *) Buffer);
+	CurPos = Buffer.length();
 }
 
 void Console::HistoryAdd(bool force)
 {
-	int i;
-
-	if (!force && !Buffer[0])
-		return;
-	for (i=0;i<HistMax;i++) {
-		if (!strnicmp((const char *) History[i],(const char *) Buffer,max) )
-			return;
-	}
-	if (History[0][0]) {
-		for (i=HISTORY_SIZE-1; i>0; i--) {
-			memcpy(History[i], History[i-1], max);
-		}
-	}
-	memcpy(History[0], Buffer, max);
-	if (HistMax<HISTORY_SIZE) {
-		HistMax++;
+	if (force || Buffer.length()) {
+		History.Append(Buffer, !force);
 	}
 }
 
@@ -226,7 +190,7 @@ void Console::SetFocus(bool focus)
 	}
 }
 
-bool Console::SetEvent(int /*eventType*/, EventHandler /*handler*/)
+bool Console::SetEvent(int /*eventType*/, ControlEventHandler /*handler*/)
 {
 	return false;
 }
