@@ -253,9 +253,7 @@ GameControl::~GameControl(void)
 		formations = NULL;
 	}
 	delete dialoghandler;
-	if (DisplayText) {
-		core->FreeString(DisplayText);
-	}
+	delete DisplayText;
 }
 
 // ArrowSprite cycles
@@ -594,17 +592,17 @@ void GameControl::DrawInternal(Region& screen)
 	if (DebugFlags & DEBUG_SHOW_LIGHTMAP) {
 		Sprite2D* spr = area->LightMap->GetSprite2D();
 		video->BlitSprite( spr, 0, 0, true );
-		video->FreeSprite( spr );
+		Sprite2D::FreeSprite( spr );
 		Region point( p.x / 16, p.y / 12, 2, 2 );
 		video->DrawRect( point, ColorRed );
 	}
 
 	if (core->HasFeature(GF_ONSCREEN_TEXT) && DisplayText) {
-		core->GetFont(1)->Print(screen, (unsigned char *)DisplayText, core->InfoTextPalette, IE_FONT_ALIGN_CENTER | IE_FONT_ALIGN_MIDDLE, true);
+		core->GetTextFont()->Print(screen, *DisplayText, core->InfoTextPalette, IE_FONT_ALIGN_CENTER | IE_FONT_ALIGN_MIDDLE);
 		if (update_scripts) {
 			// just replicating original engine behaviour
 			if (DisplayTextTime == 0) {
-				SetDisplayText((char *)NULL, 0);
+				SetDisplayText((String*)NULL, 0);
 			} else {
 				DisplayTextTime--;
 			}
@@ -812,7 +810,10 @@ bool GameControl::OnKeyRelease(unsigned char Key, unsigned short Mod)
 					overDoor->DetectTrap(256, lastActorID);
 				}
 				break;
-			// e, f
+			case 'e':// reverses pc order (useful for parties bigger than 6)
+				game->ReversePCs();
+				break;
+			// f
 			case 'g'://shows loaded areas and other game information
 				game->dump();
 				break;
@@ -1101,7 +1102,6 @@ void GameControl::DisplayTooltip() {
 					} else {
 						// non-neutral, not in party: display injured string
 						int strindex;
-						char *injuredstring = NULL;
 						// these boundaries are just a guess
 						if (hp == maxhp) {
 							strindex = STR_UNINJURED;
@@ -1115,16 +1115,14 @@ void GameControl::DisplayTooltip() {
 							strindex = STR_INJURED4;
 						}
 						strindex = displaymsg->GetStringReference(strindex);
-						if (strindex != -1) {
-							injuredstring = core->GetString(strindex, 0);
-						}
+						String* injuredstring = core->GetString(strindex, 0);
 
 						if (!injuredstring) {
 							// eek, where did the string go?
 							snprintf(buffer, 100, "%s\n%d/%d", name, hp, maxhp);
 						} else {
-							snprintf(buffer, 100, "%s\n%s", name, injuredstring);
-							free(injuredstring);
+							snprintf(buffer, 100, "%s\n%ls", name, injuredstring->c_str());
+							delete injuredstring;
 						}
 					}
 				}
@@ -1271,6 +1269,12 @@ void GameControl::OnMouseOver(unsigned short x, unsigned short y)
 		//nextCursor = overInfoPoint->Cursor;
 		nextCursor = GetCursorOverInfoPoint(overInfoPoint);
 	}
+	// recheck in case the positioon was different, resulting in a new isVisible check
+	if (nextCursor == IE_CURSOR_INVALID) {
+		Owner->Cursor = IE_CURSOR_BLOCKED;
+		lastCursor = IE_CURSOR_BLOCKED;
+		return;
+	}
 
 	if (overDoor) {
 		overDoor->Highlight = false;
@@ -1294,6 +1298,13 @@ void GameControl::OnMouseOver(unsigned short x, unsigned short y)
 		if (overContainer) {
 			nextCursor = GetCursorOverContainer(overContainer);
 		}
+		// recheck in case the positioon was different, resulting in a new isVisible check
+		// fixes bg2 long block door in ar0801 above vamp beds, crashing on mouseover (too big)
+		if (nextCursor == IE_CURSOR_INVALID) {
+			Owner->Cursor = IE_CURSOR_BLOCKED;
+			lastCursor = IE_CURSOR_BLOCKED;
+			return;
+		}
 
 		Actor *prevActor = lastActor;
 		// let us target party members even if they are invisible
@@ -1505,7 +1516,7 @@ void GameControl::UpdateScrolling() {
 	Sprite2D* cursor = core->GetScrollCursorSprite(cursorFrame, numScrollCursor);
 	Video* video = core->GetVideoDriver();
 	video->SetCursor(cursor, VID_CUR_DRAG);
-	video->FreeSprite(cursor);
+	Sprite2D::FreeSprite(cursor);
 
 	numScrollCursor = (numScrollCursor+1) % 15;
 }
@@ -1780,10 +1791,9 @@ bool GameControl::HandleActiveRegion(InfoPoint *trap, Actor * actor, Point &p)
 			return false;
 		case ST_TRIGGER:
 			// always display overhead text; totsc's ar0511 library relies on it
-			if (trap->overHeadText) {
-				if (trap->textDisplaying != 1) {
-					trap->textDisplaying = 1;
-					trap->timeStartDisplaying = core->GetGame()->Ticks;
+			if (!trap->GetOverheadText().empty()) {
+				if (!trap->OverheadTextIsDisplaying()) {
+					trap->DisplayOverheadText(true);
 					DisplayString( trap );
 				}
 			}
@@ -2034,7 +2044,6 @@ void GameControl::OnMouseUp(unsigned short x, unsigned short y, unsigned short B
 	}
 	FormationRotation = false;
 	core->GetEventMgr()->FakeMouseMove();
-	return;
 }
 
 void GameControl::OnMouseWheelScroll(short x, short y)
@@ -2350,14 +2359,14 @@ bool GameControl::SetGUIHidden(bool hide)
 	WINDOW_RESIZE_OPERATION op = hide ? WINDOW_EXPAND : WINDOW_CONTRACT;
 	for (;i >= 0 && i <= 5; i+=inc) {
 		const char** val = keys[i];
-		Log(MESSAGE, "GameControl", "window: %s", *val);
+		//Log(MESSAGE, "GameControl", "window: %s", *val);
 		if (dict->Lookup( *val, index )) {
 			if (index != (ieDword) -1) {
 				Window* w = core->GetWindow(index);
 				if (w) {
 					core->SetVisible(index, !hide);
 					if (dict->Lookup( *++val, index )) {
-						Log(MESSAGE, "GameControl", "position: %s", *val);
+						//Log(MESSAGE, "GameControl", "position: %s", *val);
 						ResizeParentWindowFor( w, index, op );
 						continue;
 					}
@@ -2424,38 +2433,20 @@ void GameControl::ResizeParentWindowFor(Window* win, int type, WINDOW_RESIZE_OPE
 	}
 }
 
-//Create an overhead text over an arbitrary point
-// UNUSED
-void GameControl::DisplayString(const Point &p, const char *Text)
-{
-	Scriptable* scr = new Scriptable( ST_TRIGGER );
-	scr->overHeadText = (char *) Text;
-	scr->textDisplaying = 1;
-	scr->timeStartDisplaying = 0;
-	scr->Pos = p;
-}
-
 //Create an overhead text over a scriptable target
 //Multiple texts are possible, as this code copies the text to a new object
 void GameControl::DisplayString(Scriptable* target)
 {
 	Scriptable* scr = new Scriptable( ST_TRIGGER );
-	scr->overHeadText = strdup( target->overHeadText );
-/* strdup should work here, we use it elsewhere
-	size_t len = strlen( target->overHeadText ) + 1;
-	scr->overHeadText = ( char * ) malloc( len );
-	strcpy( scr->overHeadText, target->overHeadText );
-*/
-	scr->textDisplaying = 1;
-	scr->timeStartDisplaying = target->timeStartDisplaying;
+	scr->SetOverheadText(target->GetOverheadText());
 	scr->Pos = target->Pos;
 
 	// add as a "subtitle" to the main message window
 	ieDword tmp = 0;
 	core->GetDictionary()->Lookup("Duplicate Floating Text", tmp);
-	if (tmp) {
+	if (tmp && !target->GetOverheadText().empty()) {
 		// pass NULL target so pst does not display multiple
-		displaymsg->DisplayString(target->overHeadText, NULL);
+		displaymsg->DisplayString(target->GetOverheadText());
 	}
 }
 
@@ -2556,7 +2547,7 @@ Sprite2D* GameControl::GetPreview()
 	Sprite2D *screenshot = GetScreenshot( Region(x, y, w, h) );
 
 	Sprite2D* preview = video->SpriteScaleDown ( screenshot, 5 );
-	video->FreeSprite( screenshot );
+	Sprite2D::FreeSprite( screenshot );
 	return preview;
 }
 
@@ -2588,7 +2579,7 @@ Sprite2D* GameControl::GetPortraitPreview(int pcslot)
 		return img;
 
 	Sprite2D* img_scaled = video->SpriteScaleDown( img, ratio );
-	video->FreeSprite( img );
+	Sprite2D::FreeSprite( img );
 
 	return img_scaled;
 }
@@ -2652,16 +2643,14 @@ void GameControl::SetupCasting(ieResRef spellname, int type, int level, int idx,
 }
 
 //another method inherited from Control which has no use here
-bool GameControl::SetEvent(int /*eventType*/, EventHandler /*handler*/)
+bool GameControl::SetEvent(int /*eventType*/, ControlEventHandler /*handler*/)
 {
 	return false;
 }
 
-void GameControl::SetDisplayText(char *text, unsigned int time)
+void GameControl::SetDisplayText(String* text, unsigned int time)
 {
-	if (DisplayText) {
-		core->FreeString(DisplayText);
-	}
+	delete DisplayText;
 	DisplayTextTime = time;
 	DisplayText = text;
 }
