@@ -441,16 +441,14 @@ static bool GetItemContainer(CREItem &itemslot2, Inventory *inventory, const ieR
 
 void DisplayStringCore(Scriptable* const Sender, int Strref, int flags)
 {
-	StringBlock sb;
-	char Sound[_MAX_PATH];
-
 	//no one hears you when you are in the Limbo!
 	if (!Sender->GetCurrentArea()) {
 		return;
 	}
 
-	memset(&sb,0,sizeof(sb));
-	Sound[0]=0;
+	char Sound[_MAX_PATH] = "";
+	ieResRef soundRef = {};
+
 	Log(MESSAGE, "GameScript", "Displaying string on: %s", Sender->GetScriptName() );
 	if (flags & DS_CONST) {
 		if (Sender->Type!=ST_ACTOR) {
@@ -466,12 +464,12 @@ void DisplayStringCore(Scriptable* const Sender, int Strref, int flags)
 		int tmp=(int) actor->GetVerbalConstant(Strref);
 		if (tmp <= 0 || (actor->GetStat(IE_MC_FLAGS) & MC_EXPORTABLE)) {
 			//get soundset based string constant
-			actor->ResolveStringConstant( sb.Sound, (unsigned int) Strref);
+			actor->ResolveStringConstant(soundRef, (unsigned int) Strref);
 			if (actor->PCStats && actor->PCStats->SoundFolder[0]) {
 				snprintf(Sound, _MAX_PATH, "%s/%s",
-					actor->PCStats->SoundFolder, sb.Sound);
+					actor->PCStats->SoundFolder, soundRef);
 			} else {
-				memcpy(Sound, sb.Sound, sizeof(ieResRef) );
+				memcpy(Sound, soundRef, sizeof(ieResRef) );
 			}
 		}
 		Strref = tmp;
@@ -484,26 +482,25 @@ void DisplayStringCore(Scriptable* const Sender, int Strref, int flags)
 		}
 	}
 
-	if ((Strref != -1) && !sb.Sound[0]) {
-		sb = core->strings->GetStringBlock( Strref );
+	if ((Strref != -1) && !soundRef[0]) {
+		StringBlock sb = core->strings->GetStringBlock( Strref );
 		memcpy(Sound, sb.Sound, sizeof(ieResRef) );
-		if (sb.text[0] && strcmp(sb.text," ") && (flags & DS_CONSOLE)) {
-			//can't play the sound here, we have to delay action
-			//and for that, we have to know how long the text takes
-			if(flags&DS_NONAME) {
-				displaymsg->DisplayString( sb.text );
-			} else {
-				displaymsg->DisplayStringName( Strref, DMC_WHITE, Sender, 0);
+		if (sb.text) {
+			if (flags & DS_CONSOLE) {
+				//can't play the sound here, we have to delay action
+				//and for that, we have to know how long the text takes
+				if(flags&DS_NONAME) {
+					displaymsg->DisplayString(*sb.text);
+				} else {
+					displaymsg->DisplayStringName( Strref, DMC_WHITE, Sender, 0);
+				}
 			}
-		}
-		if (sb.text[0] && strcmp(sb.text," ") && (flags & (DS_HEAD | DS_AREA))) {
-			Sender->DisplayHeadText( sb.text );
-			//don't free sb.text, it is residing in Sender
-			if (flags & DS_AREA) {
-				Sender->FixHeadTextPos();
+			if (flags & (DS_HEAD | DS_AREA)) {
+				Sender->SetOverheadText( *sb.text );
+				if (flags & DS_AREA) {
+					Sender->FixHeadTextPos();
+				}
 			}
-		} else {
-			core->FreeString( sb.text );
 		}
 	}
 	if (Sound[0] && !(flags&DS_SILENT) ) {
@@ -922,7 +919,7 @@ static ieResRef PlayerDialogRes = "PLAYERx\0";
 
 void BeginDialog(Scriptable* Sender, Action* parameters, int Flags)
 {
-	Scriptable* tar, *scr;
+	Scriptable* tar = NULL, *scr = NULL;
 
 	if (InDebug&ID_VARIABLES) {
 		Log(MESSAGE, "GSUtils", "BeginDialog core");
@@ -934,6 +931,7 @@ void BeginDialog(Scriptable* Sender, Action* parameters, int Flags)
 		scr = Sender;
 	}
 	if (!scr) {
+		assert(Sender);
 		Log(ERROR, "GameScript", "Speaker for dialog couldn't be found (Sender: %s, Type: %d) Flags:%d.",
 			Sender->GetScriptName(), Sender->Type, Flags);
 		Sender->ReleaseCurrentAction();
@@ -1079,13 +1077,6 @@ void BeginDialog(Scriptable* Sender, Action* parameters, int Flags)
 			break;
 	}
 
-
-	//dialog is not meaningful
-	if (!Dialog || Dialog[0]=='*') {
-		Sender->ReleaseCurrentAction();
-		return;
-	}
-
 	// moved this here from InitDialog, because InitDialog doesn't know which side is which
 	// post-swap (and non-actors always have IF_NOINT set) .. also added a check that it's
 	// actually busy doing something, for the same reason
@@ -1125,47 +1116,40 @@ void BeginDialog(Scriptable* Sender, Action* parameters, int Flags)
 		if (scr->Type==ST_ACTOR) {
 			// might not be equal to speaker anymore due to swapping
 			Actor *talker = (Actor *) scr;
-			talker->SetOrientation(GetOrient( tar->Pos, scr->Pos), true);
-			if (talker->InParty) {
-				talker->SetStance(IE_ANI_READY);
+			if (!talker->Immobile() && !(talker->GetStat(IE_STATE_ID) & STATE_SLEEP)) {
+				talker->SetOrientation(GetOrient( tar->Pos, scr->Pos), true);
+				if (talker->InParty) {
+					talker->SetStance(IE_ANI_READY);
+				}
 			}
 		}
 		if (tar->Type==ST_ACTOR) {
 			// might not be equal to target anymore due to swapping
 			Actor *talkee = (Actor *) tar;
-			talkee->SetOrientation(GetOrient( scr->Pos, tar->Pos), true);
-			if (talkee->InParty) {
-				talkee->SetStance(IE_ANI_READY);
+			if (!talkee->Immobile() && !(talkee->GetStat(IE_STATE_ID) & STATE_SLEEP)) {
+				talkee->SetOrientation(GetOrient( scr->Pos, tar->Pos), true);
+				if (talkee->InParty) {
+					talkee->SetStance(IE_ANI_READY);
+				}
 			}
 		}
 	}
 
-	bool ret;
-
-	if (Dialog[0]) {
-		//increasing NumTimesTalkedTo or NumTimesInteracted
-		if (Flags & BD_TALKCOUNT) {
-			gc->SetDialogueFlags(DF_TALKCOUNT, BM_OR);
-		} else if ((Flags & BD_LOCMASK) == BD_INTERACT) {
-			gc->SetDialogueFlags(DF_INTERACT, BM_OR);
-		}
-
-		core->GetDictionary()->SetAt("DialogChoose",(ieDword) -1);
-		ret = gc->dialoghandler->InitDialog( scr, tar, Dialog);
+	//increasing NumTimesTalkedTo or NumTimesInteracted
+	if (Flags & BD_TALKCOUNT) {
+		gc->SetDialogueFlags(DF_TALKCOUNT, BM_OR);
+	} else if ((Flags & BD_LOCMASK) == BD_INTERACT) {
+		gc->SetDialogueFlags(DF_INTERACT, BM_OR);
 	}
-	else {
-		ret = false;
+
+	core->GetDictionary()->SetAt("DialogChoose",(ieDword) -1);
+	if (!gc->dialoghandler->InitDialog(scr, tar, Dialog)) {
+		if (!(Flags & BD_NOEMPTY)) {
+			displaymsg->DisplayConstantStringName(STR_NOTHINGTOSAY, DMC_RED, tar);
+		}
 	}
 
 	Sender->ReleaseCurrentAction();
-
-	if (!ret) {
-		if (Flags & BD_NOEMPTY) {
-			return;
-		}
-		displaymsg->DisplayConstantStringName(STR_NOTHINGTOSAY, DMC_RED, tar);
-		return;
-	}
 }
 
 static EffectRef fx_movetoarea_ref = { "MoveToArea", -1 };
@@ -1272,6 +1256,8 @@ void MoveToObjectCore(Scriptable *Sender, Action *parameters, ieDword flags, boo
 		}
 		actor->AddActionInFront(newaction);
 		actor->SetWait(1);
+	} else {
+		delete newaction;
 	}
 
 	Sender->ReleaseCurrentAction();
@@ -1352,6 +1338,7 @@ void AttackCore(Scriptable *Sender, Scriptable *target, int flags)
 	if (!header || !actor->WeaponIsUsable(leftorright, header)) {
 		actor->StopAttack();
 		Sender->ReleaseCurrentAction();
+		assert(tar);
 		actor->AddTrigger(TriggerEntry(trigger_unusable, tar->GetGlobalID()));
 		Log(WARNING, "AttackCore", "Weapon unusable: %s!", actor->GetName(1));
 		return;
@@ -1973,7 +1960,9 @@ Trigger *GenerateTriggerCore(const char *src, const char *str, int trIndex, int
 				else {
 					i=0;
 				}
-				while (*src != '"' && *src != '#') {
+				// some iwd2 dialogs use # instead of " for delimiting parameters (11phaen)
+				// BUT at the same time, some bg2 mod prefixes use it too (eg. Tashia)
+				while (*src != '"' && (*src != '#' || (*(src-1) != '(' && *(src-1) != ','))) {
 					if (*src == 0) {
 						delete newTrigger;
 						return NULL;
@@ -2009,7 +1998,7 @@ Trigger *GenerateTriggerCore(const char *src, const char *str, int trIndex, int
 					}
 					//reading the context string
 					i=0;
-					while (*src != '"' && *src != '#') {
+					while (*src != '"' && (*src != '#' || (*(src-1) != '(' && *(src-1) != ','))) {
 						if (*src == 0) {
 							delete newTrigger;
 							return NULL;
@@ -2637,6 +2626,14 @@ void SpellCore(Scriptable *Sender, Action *parameters, int flags)
 {
 	ieResRef spellres;
 	int level = 0;
+	static bool third = core->HasFeature(GF_3ED_RULES);
+	Scriptable *pretarget = NULL;
+
+	// handle iwd2 marked spell casting (MARKED_SPELL is 0)
+	if (third && parameters->int0Parameter == 0) {
+		parameters->int0Parameter = Sender->LastMarkedSpell;
+		pretarget = Sender->GetCurrentArea()->GetActorByGlobalID(Sender->LastMarked);
+	}
 
 	//resolve spellname
 	if (!ResolveSpellName( spellres, parameters) ) {
@@ -2680,7 +2677,9 @@ void SpellCore(Scriptable *Sender, Action *parameters, int flags)
 	}
 
 	Scriptable* tar = GetStoredActorFromObject( Sender, parameters->objects[1], seeflag );
-	if (!tar) {
+	if (pretarget) {
+		tar = pretarget;
+	} else if (!tar) {
 		Sender->ReleaseCurrentAction();
 		if (act) {
 			act->SetStance(IE_ANI_READY);
