@@ -45,7 +45,6 @@ private:
 
 	int fadeToCounter, fadeToMax;
 	int fadeFromCounter, fadeFromMax;
-	unsigned long waitCounter;
 	int shakeCounter;
 	int shakeX, shakeY;
 	unsigned int first_animation;
@@ -69,7 +68,6 @@ public:
 	void SetMoveViewPort(ieDword x, ieDword y, int spd, bool center);
 	void SetFadeToColor(unsigned long Count);
 	void SetFadeFromColor(unsigned long Count);
-	void SetWait(unsigned long Count);
 	void SetScreenShake(int shakeX, int shakeY, unsigned long Count);
 	void AddAnimation(ControlAnimation* ctlanim, unsigned long time);
 	void RemoveAnimation(ControlAnimation* ctlanim);
