@@ -1224,7 +1224,7 @@ bool Inventory::SetEquippedSlot(ieWordSigned slotcode, ieWord header)
 	EquippedHeader = header;
 
 	//doesn't work if magic slot is used, refresh the magic slot just in case
-	if (HasItemInSlot("",SLOT_MAGIC) && (slotcode!=SLOT_MAGIC-SLOT_MELEE)) {
+	if (MagicSlotEquipped() && (slotcode!=SLOT_MAGIC-SLOT_MELEE)) {
 		Equipped = SLOT_MAGIC-SLOT_MELEE;
 		UpdateWeaponAnimation();
 		return false;
@@ -1291,6 +1291,17 @@ int Inventory::GetEquippedHeader() const
 	return EquippedHeader;
 }
 
+// store this internally just like Equipped/EquippedHeader if it turns into a hot path
+ITMExtHeader *Inventory::GetEquippedExtHeader(int header) const
+{
+	int slot; // Equipped holds the projectile, not the weapon
+	CREItem *itm = GetUsedWeapon(false, slot); // check the main hand only
+	if (!itm) return NULL;
+	Item *item = gamedata->GetItem(itm->ItemResRef, true);
+	if (!item) return NULL;
+	return item->GetExtHeader(header);
+}
+
 void Inventory::SetEquipped(ieWordSigned slot, ieWord header)
 {
 	Equipped = slot;
@@ -1302,6 +1313,14 @@ bool Inventory::FistsEquipped() const
 	return Equipped == IW_NO_EQUIPPED;
 }
 
+bool Inventory::MagicSlotEquipped() const
+{
+	if (SLOT_MAGIC != -1) {
+		return Slots[SLOT_MAGIC] != NULL;
+	}
+	return false;
+}
+
 //returns the fist weapon if there is nothing else
 //This will return the actual weapon, I mean the bow in the case of bow+arrow combination
 CREItem *Inventory::GetUsedWeapon(bool leftorright, int &slot) const
@@ -1625,6 +1644,7 @@ bool Inventory::GetEquipmentInfo(ItemExtHeader *array, int startindex, int count
 				memcpy(array[pos].itemname, slot->ItemResRef, sizeof(ieResRef) );
 				array[pos].slot = idx;
 				array[pos].headerindex = ehc;
+				array[pos].Tooltip = ext_header->Tooltip;
 				int slen = ((char *) &(array[pos].itemname)) -((char *) &(array[pos].AttackType));
 				memcpy(&(array[pos].AttackType), &(ext_header->AttackType), slen);
 				if (ext_header->Charges) {
@@ -1716,6 +1736,7 @@ void Inventory::UpdateWeaponAnimation()
 			}
 			if (si) {
 				Item* it = gamedata->GetItem(si->ItemResRef, true);
+				assert(it);
 				if (core->CanUseItemType(SLOT_WEAPON, it))
 					twoweapon = true;
 				gamedata->FreeItem(it, si->ItemResRef, false);
@@ -1769,7 +1790,7 @@ int Inventory::WhyCantEquip(int slot, int twohanded) const
 	}
 
 	//magic items have the highest priority
-	if ( HasItemInSlot("", SLOT_MAGIC)) {
+	if (MagicSlotEquipped()) {
 		//magic weapon is in use
 		return STR_MAGICWEAPON;
 	}
