@@ -24,6 +24,8 @@
 #include "exports.h"
 #include "Variables.h"
 
+namespace GemRB {
+
 class Variables;
 
 class GEM_EXPORT KeyMap {
@@ -33,7 +35,7 @@ public:
 	KeyMap();
 	~KeyMap();
 	bool InitializeKeyMap(const char *inifile, const char *keyfile);
-	void ResolveKey(int key, int group);
+	bool ResolveKey(int key, int group);
 };
 
 class Function {
@@ -45,4 +47,6 @@ public:
 	Function(const char *m, const char *f, int g);
 };
 
+}
+
 #endif
