@@ -20,6 +20,8 @@
 #ifndef PATHFINDER_H
 #define PATHFINDER_H
 
+namespace GemRB {
+
 //searchmap conversion bits
 
 enum {
@@ -49,4 +51,6 @@ struct PathNode {
 	unsigned int orient;
 };
 
+}
+
 #endif
