@@ -106,7 +106,7 @@ Projectile::~Projectile()
 			if(shadow[i])
 				delete shadow[i];
 		}
-		core->GetVideoDriver()->FreeSprite(light);
+		Sprite2D::FreeSprite(light);
 	}
 
 	if(children) {
@@ -456,8 +456,13 @@ Actor *Projectile::GetTarget()
 			return NULL;
 		}
 		if (res==-1) {
-			Target = original->GetGlobalID();
-			return NULL;
+			if (original) {
+				Target = original->GetGlobalID();
+				target = original;
+			} else {
+				Log(DEBUG, "Projectile", "GetTarget: caster not found, bailing out!");
+				return NULL;
+			}
 		}
 		effects->SetOwner(original);
 		return target;
@@ -558,8 +563,8 @@ void Projectile::Payload()
 
 	if (Target) {
 		target = GetTarget();
-		if (!target && (Target==Caster)) {
-			//projectile rebounced
+		if (!target) {
+			//projectile resisted or failed to bounce properly
 			return;
 		}
 	} else {
