@@ -25,6 +25,9 @@
 #include "Resource.h"
 #include "ResourceDesc.h"
 #include "ResourceSource.h"
+#include "System/StringBuffer.h"
+
+namespace GemRB {
 
 ResourceManager::ResourceManager()
 {
@@ -39,6 +42,7 @@ bool ResourceManager::AddSource(const char *path, const char *description, Plugi
 {
 	PluginHolder<ResourceSource> source(type);
 	if (!source->Open(path, description)) {
+		Log(WARNING, "ResourceManager", "Invalid path given: %s (%s)", path, description);
 		return false;
 	}
 
@@ -55,11 +59,11 @@ bool ResourceManager::AddSource(const char *path, const char *description, Plugi
 	return true;
 }
 
-static void PrintPossibleFiles(const char* ResRef, const TypeID *type)
+static void PrintPossibleFiles(StringBuffer& buffer, const char* ResRef, const TypeID *type)
 {
 	const std::vector<ResourceDesc>& types = PluginMgr::Get()->GetResourceDesc(type);
 	for (size_t j = 0; j < types.size(); j++) {
-		printf("%s%s ", ResRef, types[j].GetExt());
+		buffer.appendFormatted("%s.%s ", ResRef, types[j].GetExt());
 	}
 }
 
@@ -74,9 +78,8 @@ bool ResourceManager::Exists(const char *ResRef, SClass_ID type, bool silent) co
 		}
 	}
 	if (!silent) {
-		printMessage( "ResourceManager", "Searching for ", WHITE );
-		printf( "%s%s...", ResRef, core->TypeExt( type ) );
-		printStatus( "NOT FOUND", YELLOW );
+		Log(WARNING, "ResourceManager", "'%s.%s' not found...",
+			ResRef, core->TypeExt(type));
 	}
 	return false;
 }
@@ -95,11 +98,11 @@ bool ResourceManager::Exists(const char *ResRef, const TypeID *type, bool silent
 		}
 	}
 	if (!silent) {
-		printMessage( "ResourceManager", "Searching for ", WHITE );
-		printf( "%s... ", ResRef );
-		printf("Tried ");
-		PrintPossibleFiles(ResRef,type);
-		printStatus( "NOT FOUND", YELLOW );
+		StringBuffer buffer;
+		buffer.appendFormatted("Couldn't find '%s'... ", ResRef);
+		buffer.append("Tried ");
+		PrintPossibleFiles(buffer, ResRef,type);
+		Log(WARNING, "ResourceManager", buffer);
 	}
 	return false;
 }
@@ -108,21 +111,19 @@ DataStream* ResourceManager::GetResource(const char* ResRef, SClass_ID type, boo
 {
 	if (ResRef[0] == '\0')
 		return NULL;
-	if (!silent) {
-		printMessage( "ResourceManager", "Searching for ", WHITE );
-		printf( "%s%s...", ResRef, core->TypeExt( type ) );
-	}
 	for (size_t i = 0; i < searchPath.size(); i++) {
 		DataStream *ds = searchPath[i]->GetResource(ResRef, type);
 		if (ds) {
 			if (!silent) {
-				printStatus( searchPath[i]->GetDescription(), GREEN );
+				Log(MESSAGE, "ResourceManager", "Found '%s.%s' in '%s'.",
+					ResRef, core->TypeExt(type), searchPath[i]->GetDescription());
 			}
 			return ds;
 		}
 	}
 	if (!silent) {
-		printStatus( "ERROR", LIGHT_RED );
+		Log(ERROR, "ResourceManager", "Couldn't find '%s.%s'.",
+			ResRef, core->TypeExt(type));
 	}
 	return NULL;
 }
@@ -132,8 +133,7 @@ Resource* ResourceManager::GetResource(const char* ResRef, const TypeID *type, b
 	if (ResRef[0] == '\0')
 		return NULL;
 	if (!silent) {
-		printMessage( "ResourceManager", "Searching for ", WHITE );
-		printf( "%s... ", ResRef );
+		Log(MESSAGE, "ResourceManager", "Searching for '%s'...", ResRef);
 	}
 	const std::vector<ResourceDesc> &types = PluginMgr::Get()->GetResourceDesc(type);
 	for (size_t j = 0; j < types.size(); j++) {
@@ -143,8 +143,8 @@ Resource* ResourceManager::GetResource(const char* ResRef, const TypeID *type, b
 				Resource *res = types[j].Create(str);
 				if (res) {
 					if (!silent) {
-						printf( "%s%s...", ResRef, types[j].GetExt() );
-						printStatus( searchPath[i]->GetDescription(), GREEN );
+						Log(MESSAGE, "ResourceManager", "Found '%s.%s' in '%s'.",
+							ResRef, types[j].GetExt(), searchPath[i]->GetDescription());
 					}
 					return res;
 				}
@@ -152,9 +152,13 @@ Resource* ResourceManager::GetResource(const char* ResRef, const TypeID *type, b
 		}
 	}
 	if (!silent) {
-		printf("Tried ");
-		PrintPossibleFiles(ResRef,type);
-		printStatus( "ERROR", LIGHT_RED );
+		StringBuffer buffer;
+		buffer.appendFormatted("Couldn't find '%s'... ", ResRef);
+		buffer.append("Tried ");
+		PrintPossibleFiles(buffer, ResRef,type);
+		Log(WARNING, "ResourceManager", buffer);
 	}
 	return NULL;
 }
+
+}
