@@ -27,6 +27,8 @@
 
 #include "Plugin.h"
 
+namespace GemRB {
+
 class DataStream;
 class ResourceDesc;
 
@@ -44,4 +46,6 @@ protected:
 	char *description;
 };
 
+}
+
 #endif
