@@ -22,12 +22,14 @@
 #define CONTAINER_H
 
 #include "Inventory.h"
-#include "Scriptable.h"
+#include "Scriptable/Scriptable.h"
+
+namespace GemRB {
 
 //container flags
 #define CONT_LOCKED      1
 #define CONT_RESET       8
-#define CONT_DISABLED    32
+#define CONT_DISABLED    (32|128)   //bg2 and pst uses different bits, luckily they are not overlapping
 
 class GEM_EXPORT Container : public Highlightable {
 public:
@@ -48,7 +50,7 @@ public:
 	void TryPickLock(Actor *actor);
 	void TryBashLock(Actor* actor) ;
 	bool TryUnlock(Actor *actor);
-	void DebugDump() const;
+	void dump() const;
 	int TrapResets() const { return Flags & CONT_RESET; }
 private:
 	//updates the ground icons for a pile
@@ -68,4 +70,6 @@ public:
 	//keyresref is stored in Highlightable
 };
 
+}
+
 #endif
