@@ -240,6 +240,10 @@ EffectQueue *Spell::GetEffectBlock(Scriptable *self, const Point &pos, int block
 			}
 		}
 
+		if (fx->Target != FX_TARGET_PRESET && EffectQueue::OverrideTarget(fx)) {
+			fx->Target = FX_TARGET_PRESET;
+		}
+
 		if (fx->Target != FX_TARGET_SELF) {
 			fx->Projectile = pro;
 			fxqueue->AddEffect( fx );
