@@ -24,6 +24,8 @@
 
 #include <ctype.h>
 
+namespace GemRB {
+
 static const char* GEM_ENCRYPTION_KEY = "\x88\xa8\x8f\xba\x8a\xd3\xb9\xf5\xed\xb1\xcf\xea\xaa\xe4\xb5\xfb\xeb\x82\xf9\x90\xca\xc9\xb5\xe7\xdc\x8e\xb7\xac\xee\xf7\xe0\xca\x8e\xea\xca\x80\xce\xc5\xad\xb7\xc4\xd0\x84\x93\xd5\xf0\xeb\xc8\xb4\x9d\xcc\xaf\xa5\x95\xba\x99\x87\xd2\x9d\xe3\x91\xba\x90\xca";
 
 static bool EndianSwitch = false;
@@ -198,6 +200,10 @@ int DataStream::ReadLine(void* buf, unsigned int maxlen)
 		return -1;
 	}
 	unsigned int i = 0;
+	//TODO: fix this to handle any combination of \r and \n
+	//Windows: \r\n
+	//Old Mac: \r
+	//otherOS: \n
 	while (i < ( maxlen - 1 )) {
 		char ch;
 		Read(&ch, 1);
@@ -218,3 +224,5 @@ DataStream* DataStream::Clone()
 {
 	return NULL;
 }
+
+}
