@@ -18,41 +18,29 @@
  *
  */
 
-/**
- * @file MemoryStream.h
- * Declares MemoryStream class, stream reading/writing data from/to a buffer in memory.
- * @author The GemRB Project
- */
-
-
 #ifndef MEMORYSTREAM_H
 #define MEMORYSTREAM_H
 
 #include "System/DataStream.h"
 
 #include "exports.h"
-#include "globals.h"
 
-/**
- * @class MemoryStream
- * Reads and writes data from/to a buffer in memory.
- */
+namespace GemRB {
 
-class GEM_EXPORT MemoryStream : public DataStream {
+class GEM_EXPORT MemoryStream : public DataStream
+{
 private:
-	void* ptr;
-	//unsigned long length;
-	bool autoFree;
+	char *data;
 public:
-	MemoryStream(void* buffer, int length, bool autoFree = true);
-	~MemoryStream(void);
+	MemoryStream(char *name, void* data, unsigned long size);
+	~MemoryStream();
+	DataStream* Clone();
+
 	int Read(void* dest, unsigned int length);
-	int Write(const void * /*src*/, unsigned int /*length*/)
-	{
-		return GEM_ERROR;
-	}
+	int Write(const void* src, unsigned int length);
 	int Seek(int pos, int startpos);
-	int ReadLine(void* buf, unsigned int maxlen);
 };
 
-#endif  // ! MEMORYSTREAM_H
+}
+
+#endif
