@@ -27,6 +27,8 @@
 #include "Scriptable/Door.h"
 #include "Scriptable/InfoPoint.h"
 
+namespace GemRB {
+
 TileMap::TileMap(void)
 {
 	XCellCount = 0;
@@ -123,6 +125,9 @@ Door* TileMap::GetDoor(const Point &p) const
 		Gem_Polygon *doorpoly;
 
 		Door* door = doors[i];
+		if (door->Flags&DOOR_HIDDEN) {
+			continue;
+		}
 		if (door->Flags&DOOR_OPEN)
 			doorpoly = door->open;
 		else
@@ -205,12 +210,12 @@ void TileMap::AddRainOverlay(TileOverlay* overlay)
 	rain_overlays.push_back( overlay );
 }
 
-void TileMap::DrawOverlays(Region screen, int rain)
+void TileMap::DrawOverlays(Region screen, int rain, int flags)
 {
 	if (rain) {
-		overlays[0]->Draw( screen, rain_overlays );
+		overlays[0]->Draw( screen, rain_overlays, flags );
 	} else {
-		overlays[0]->Draw( screen, overlays );
+		overlays[0]->Draw( screen, overlays, flags );
 	}
 }
 
@@ -238,7 +243,6 @@ void TileMap::DrawFogOfWar(ieByte* explored_mask, ieByte* visible_mask, Region v
 		w++;
 		h++;
 	}
-	Color black = { 0, 0, 0, 255 };
 
 	Video* vid = core->GetVideoDriver();
 	Region vp = vid->GetViewport();
@@ -274,7 +278,7 @@ void TileMap::DrawFogOfWar(ieByte* explored_mask, ieByte* visible_mask, Region v
 			Region r = Region(x0 + viewport.x + ( (x - sx) * CELL_SIZE ), y0 + viewport.y + ( (y - sy) * CELL_SIZE ), CELL_SIZE, CELL_SIZE);
 			if (! IS_EXPLORED( x, y )) {
 				// Unexplored tiles are all black
-				vid->DrawRect(r, black, true, true);
+				vid->DrawRect(r, ColorBlack, true, true);
 				continue;  // Don't draw 'invisible' fog
 			}
 			else {
@@ -335,7 +339,7 @@ void TileMap::DrawFogOfWar(ieByte* explored_mask, ieByte* visible_mask, Region v
 					FOG( 12 );
 					break;
 				case 15: //this is black too
-					vid->DrawRect(r, black, true, true);
+					vid->DrawRect(r, ColorBlack, true, true);
 					break;
 				}
 			}
@@ -513,8 +517,8 @@ int TileMap::CleanupContainer(Container *container)
 			return 1;
 		}
 	}
-	printMessage("TileMap", " ", LIGHT_RED);
-	printf("Invalid container cleanup: %s\n", container->GetScriptName());
+	Log(ERROR, "TileMap", "Invalid container cleanup: %s",
+		container->GetScriptName());
 	return 1;
 }
 
@@ -647,3 +651,5 @@ Point TileMap::GetMapSize()
 {
 	return Point((short) (XCellCount*64), (short) (YCellCount*64));
 }
+
+}
