@@ -26,6 +26,8 @@
 #include "Polygon.h"
 #include "TileOverlay.h"
 
+namespace GemRB {
+
 //special container types
 #define IE_CONTAINER_PILE   4
 
@@ -90,11 +92,13 @@ public:
 	void ClearOverlays();
 	void AddOverlay(TileOverlay* overlay);
 	void AddRainOverlay(TileOverlay* overlay);
-	void DrawOverlays(Region screen, int rain);
+	void DrawOverlays(Region screen, int rain, int flags);
 	void DrawFogOfWar(ieByte* explored_mask, ieByte* visible_mask, Region viewport);
 	Point GetMapSize();
 public:
 	int XCellCount, YCellCount;
 };
 
+}
+
 #endif
