@@ -27,6 +27,8 @@
 
 #include <vector>
 
+namespace GemRB {
+
 extern bool RedrawTile;
 
 class GEM_EXPORT TileOverlay {
@@ -43,4 +45,6 @@ public:
 	void BumpViewport(const Region &viewport, Region &vp);
 };
 
+}
+
 #endif
