@@ -23,6 +23,8 @@
 #include "Interface.h" // for LoadInitialValues
 #include "System/FileStream.h" // for LoadInitialValues
 
+namespace GemRB {
+
 /////////////////////////////////////////////////////////////////////////////
 // private inlines 
 inline bool Variables::MyCopyKey(char*& dest, const char* key) const
@@ -293,7 +295,7 @@ bool Variables::Lookup(const char* key, char* dest, int MaxLength) const
 		return false; // not in map
 	}
 
-	strncpy( dest, pAssoc->Value.sValue, MaxLength );
+	strlcpy( dest, pAssoc->Value.sValue, MaxLength + 1 );
 	return true;
 }
 
@@ -426,8 +428,7 @@ void Variables::SetAt(const char* key, ieDword value, bool nocreate)
 	assert( m_type == GEM_VARIABLES_INT );
 	if (( pAssoc = GetAssocAt( key, nHash ) ) == NULL) {
 		if (nocreate) {
-			printMessage("Variables", " ", YELLOW);
-			printf("Cannot create new variable: %s\n", key);
+			Log(WARNING, "Variables", "Cannot create new variable: %s", key);
 			return;
 		}
 
@@ -480,7 +481,7 @@ void Variables::LoadInitialValues(const char* name)
 	// we only support PST's var.var for now
 	PathJoin( nPath, core->GamePath, "var.var", NULL );
 	FileStream fs;
-	if (!fs.Open( nPath, true )) {
+	if (!fs.Open(nPath)) {
 		return;
 	}
 
@@ -500,7 +501,45 @@ void Variables::LoadInitialValues(const char* name)
 		// is it the type we want? if not, skip
 		if (strnicmp(buffer, name, 6)) continue;
 		// copy variable (types got 2 extra spaces, and the name is padded too)
-		strnspccpy(varname,buffer+8,32);
+		// (true = uppercase, needed for original engine save compat, see 315b8f2e)
+		strnspccpy(varname,buffer+8,32, true);
 		SetAt(varname, value);
 	}  
 }
+
+void Variables::DebugDump()
+{
+	const char *poi;
+
+	switch(m_type) {
+	case GEM_VARIABLES_STRING:
+		poi = "string";
+		break;
+	case GEM_VARIABLES_INT:
+		poi = "int";
+		break;
+	case GEM_VARIABLES_POINTER:
+		poi = "other";
+		break;
+	default:
+		poi = "invalid";
+	}
+	Log (DEBUG, "Variables", "Item type: %s", poi);
+	Log (DEBUG, "Variables", "Item count: %d", m_nCount);
+	Log (DEBUG, "Variables", "HashTableSize: %d\n", m_nHashTableSize);
+	for (unsigned int nHash = 0; nHash < m_nHashTableSize; nHash++) {
+		Variables::MyAssoc* pAssoc;
+		for (pAssoc = m_pHashTable[nHash]; pAssoc != NULL; pAssoc = pAssoc->pNext) {
+			switch(m_type) {
+			case GEM_VARIABLES_STRING:
+				Log (DEBUG, "Variables", "%s = %s", pAssoc->key, pAssoc->Value.sValue);
+				break;
+			default:
+				Log (DEBUG, "Variables", "%s = %d", pAssoc->key, pAssoc->Value.nValue);
+				break;
+			}
+		}
+	}
+}
+
+}
