@@ -34,7 +34,7 @@
 
 #include "ie_types.h"
 
-#define VERSION_GEMRB "0.8.2"
+#define VERSION_GEMRB "0.8.3"
 
 #define GEMRB_STRING "GemRB v" VERSION_GEMRB
 
@@ -128,7 +128,7 @@ namespace GemRB {
 #define  GF_3ED_RULES              	38 //iwd2
 #define  GF_LEVELSLOT_PER_CLASS    	39 //iwd2
 #define  GF_SELECTIVE_MAGIC_RES    	40 //bg2, iwd2, (how)
-#define  GF_HAS_HIDE_IN_SHADOWS    	41 // not in bg1 and pst
+#define  GF_HAS_HIDE_IN_SHADOWS    	41 // bg2, iwd2
 #define  GF_AREA_VISITED_VAR    	42 //iwd, iwd2
 #define  GF_PROPER_BACKSTAB     	43 //bg2, iwd2, how?
 #define  GF_ONSCREEN_TEXT       	44 //pst
@@ -207,19 +207,6 @@ inline unsigned long GetTickCount()
 }
 #endif
 
-#ifndef __APPLE__
-// MIN and MAX are already similarly defined by Cocoa
-inline int MIN(int a, int b)
-{
-	return (a > b ? b : a);
-}
-
-inline int MAX(int a, int b)
-{
-	return (a < b ? b : a);
-}
-#endif
-
 inline bool valid_number(const char* string, long& val)
 {
 	char* endpr;
