@@ -31,6 +31,8 @@
 #include <cstring>
 #include <cstdlib>
 
+namespace GemRB {
+
 // IP's ACM files
 class ACMReader : public SoundMgr {
 private:
@@ -70,4 +72,6 @@ public:
 	virtual int read_samples(short* buffer, int count);
 };
 
+}
+
 #endif
