@@ -29,6 +29,8 @@
 #include "System/SlicedStream.h"
 #include "System/FileStream.h"
 
+using namespace GemRB;
+
 BIFImporter::BIFImporter(void)
 {
 	stream = NULL;
@@ -51,17 +53,17 @@ BIFImporter::~BIFImporter(void)
 
 DataStream* BIFImporter::DecompressBIFC(DataStream* compressed, const char* path)
 {
-	print( "Decompressing\n" );
+	print("Decompressing");
 	if (!core->IsAvailable( PLUGIN_COMPRESSION_ZLIB ))
 		return NULL;
 	PluginHolder<Compressor> comp(PLUGIN_COMPRESSION_ZLIB);
 	ieDword unCompBifSize;
 	compressed->ReadDword( &unCompBifSize );
-	print( "\nDecompressing file: [..........]" );
+	//print( "\nDecompressing file: [..........]" );
 	fflush(stdout);
 	FileStream out;
 	if (!out.Create(path)) {
-		printMessage("BIFImporter", "Cannot write %s.\n", RED, path);
+		Log(ERROR, "BIFImporter", "Cannot write %s.", path);
 		return NULL;
 	}
 	ieDword finalsize = 0;
@@ -76,6 +78,7 @@ DataStream* BIFImporter::DecompressBIFC(DataStream* compressed, const char* path
 		finalsize = out.GetPos();
 		if (( int ) ( finalsize * ( 10.0 / unCompBifSize ) ) != laststep) {
 			laststep++;
+			/*
 			print( "\b\b\b\b\b\b\b\b\b\b\b" );
 			int l;
 
@@ -85,9 +88,11 @@ DataStream* BIFImporter::DecompressBIFC(DataStream* compressed, const char* path
 				print( "." );
 			print( "]" );
 			fflush(stdout);
+			*/
 		}
 	}
-	print( "\n" );
+	//print("\n");
+	out.Close(); // This is necesary, since windows won't open the file otherwise.
 	return FileStream::OpenFile(path);
 }
 
@@ -98,7 +103,7 @@ DataStream* BIFImporter::DecompressBIF(DataStream* compressed, const char* /*pat
 	compressed->Seek(fnlen, GEM_CURRENT_POS);
 	compressed->ReadDword(&declen);
 	compressed->ReadDword(&complen);
-	print( "Decompressing\n" );
+	print("Decompressing");
 	return CacheCompressedStream(compressed, compressed->filename, complen);
 }
 
@@ -134,7 +139,8 @@ int BIFImporter::OpenArchive(const char* path)
 			stream = DecompressBIFC(file, cachePath);
 			delete file;
 		} else if (strncmp( Signature, "BIFFV1  ", 8 ) == 0) {
-			stream = CacheStream(file);
+			file->Seek(0, GEM_STREAM_START);
+			stream = file;
 		} else {
 			delete file;
 			return GEM_ERROR;
