@@ -159,7 +159,8 @@ Window* CHUImporter::GetWindow(unsigned int wid)
 				str->Read( &y1, 1 );
 				str->Read( &DisabledIndex, 1 );
 				str->Read( &y2, 1 );
-				btn->Owner = win;
+
+				win->AddControl( btn );
 				/** Justification comes from the .chu, other bits are set by script */
 				if (!Width) {
 					btn->SetFlags(IE_GUI_BUTTON_NO_IMAGE, BM_OR);
@@ -176,7 +177,6 @@ Window* CHUImporter::GetWindow(unsigned int wid)
 				if (strnicmp( BAMFile, "guictrl\0", 8 ) == 0) {
 					if (UnpressedIndex == 0) {
 						//printMessage("CHUImporter", "Special Button Control, Skipping Image Loading\n",GREEN );
-						win->AddControl( btn );
 						break;
 					}
 				}
@@ -187,7 +187,6 @@ Window* CHUImporter::GetWindow(unsigned int wid)
 					Log(ERROR, "CHUImporter", "Cannot Load Button Images, skipping control");
 					/* IceWind Dale 2 has fake BAM ResRefs for some Buttons,
 					this will handle bad ResRefs */
-					win->AddControl( btn );
 					break;
 				}
 				/** Cycle is only a byte for buttons */
@@ -208,7 +207,6 @@ Window* CHUImporter::GetWindow(unsigned int wid)
 				}
 				tspr = bam->GetFrame( DisabledIndex, (unsigned char) Cycle );
 				btn->SetImage( BUTTON_IMAGE_DISABLED, tspr );
-				win->AddControl( btn );
 			}
 			break;
 
@@ -252,7 +250,11 @@ Window* CHUImporter::GetWindow(unsigned int wid)
 					AnimationFactory *af = (AnimationFactory *)
 						gamedata->GetFactoryResource(BAMFile, IE_BAM_CLASS_ID );
 					/* Getting the Cycle of the bam */
+					if (af) {
 						pbar->SetAnimation(af->GetCycle( Cycle & 0xff ) );
+					} else {
+						Log(ERROR, "CHUImporter", "Couldn't create animationfactory for knob: %s", BAMFile);
+					}
 				}
 				else {
 					ResourceHolder<ImageMgr> mos(BAMFile);
@@ -372,9 +374,8 @@ Window* CHUImporter::GetWindow(unsigned int wid)
 				str->Read( &init, 4 );
 				str->Read( &back, 4 );
 				str->ReadWord( &SBID );
-				TextArea* ta = new TextArea( ctrlFrame, fore, init, back );
+				TextArea* ta = new TextArea( ctrlFrame, fnt, ini, fore, init, back );
 				ta->ControlID = ControlID;
-				ta->SetFonts( ini, fnt );
 				win->AddControl( ta );
 				if (SBID != 0xffff)
 					win->Link( SBID, ( unsigned short ) ControlID );
@@ -394,9 +395,9 @@ Window* CHUImporter::GetWindow(unsigned int wid)
 				str->Read( &fore, 4 );
 				str->Read( &back, 4 );
 				str->ReadWord( &alignment );
-				char* str = core->GetString( StrRef );
-				Label* lab = new Label( ctrlFrame, fnt, str );
-				core->FreeString( str );
+				String* str = core->GetString( StrRef );
+				Label* lab = new Label( ctrlFrame, fnt, *str );
+				delete str;
 				lab->ControlID = ControlID;
 
 				if (alignment & 1) {
