@@ -778,18 +778,20 @@ void CREImporter::ReadChrHeader(Actor *act)
 	switch (CREVersion) {
 	case IE_CRE_V2_2:
 		//gemrb format doesn't save these redundantly
+		ieResRef spell;
 		for (i=0;i<QSPCount;i++) {
-			str->ReadResRef(Signature);
-			if (Signature[0]) {
+			str->ReadResRef(spell);
+			// FIXME: why is this needed or why do we overwrite it immediately after?
+			if (spell[0]) {
 				act->PCStats->QuickSpellClass[i]=0xff;
-				memcpy(act->PCStats->QuickSpells[i], Signature, sizeof(ieResRef));
+				memcpy(act->PCStats->QuickSpells[i], spell, sizeof(ieResRef));
 			}
 		}
 		for (i=0;i<QSPCount;i++) {
-			str->ReadResRef(Signature);
-			if (Signature[0]) {
+			str->ReadResRef(spell);
+			if (spell[0]) {
 				act->PCStats->QuickSpellClass[i]=0xfe;
-				memcpy(act->PCStats->QuickSpells[i], Signature, sizeof(ieResRef));
+				memcpy(act->PCStats->QuickSpells[i], spell, sizeof(ieResRef));
 			}
 		}
 		//fallthrough
@@ -937,11 +939,11 @@ Actor* CREImporter::GetActor(unsigned char is_in_party)
 	act->InParty = is_in_party;
 	str->ReadDword( &act->LongStrRef );
 	//Beetle name in IWD needs the allow zero flag
-	char* poi = core->GetString( act->LongStrRef, IE_STR_ALLOW_ZERO );
+	char* poi = core->GetCString( act->LongStrRef, IE_STR_ALLOW_ZERO );
 	act->SetName( poi, 1 ); //setting longname
 	free( poi );
 	str->ReadDword( &act->ShortStrRef );
-	poi = core->GetString( act->ShortStrRef );
+	poi = core->GetCString( act->ShortStrRef );
 	act->SetName( poi, 2 ); //setting shortname (for tooltips)
 	free( poi );
 	act->BaseStats[IE_VISUALRANGE] = 30; //this is just a hack
@@ -2921,6 +2923,7 @@ int CREImporter::PutKnownSpells( DataStream *stream, Actor *actor)
 			unsigned int count = actor->spellbook.GetKnownSpellsCount(i, j);
 			for (unsigned int k=0;k<count;k++) {
 				CREKnownSpell *ck = actor->spellbook.GetKnownSpell(i, j, k);
+				assert(ck);
 				stream->WriteResRef(ck->SpellResRef);
 				stream->WriteWord( &ck->Level);
 				stream->WriteWord( &ck->Type);
@@ -2966,7 +2969,7 @@ int CREImporter::PutMemorizedSpells(DataStream *stream, Actor *actor)
 			unsigned int count = actor->spellbook.GetMemorizedSpellsCount(i,j, false);
 			for (unsigned int k=0;k<count;k++) {
 				CREMemorizedSpell *cm = actor->spellbook.GetMemorizedSpell(i,j,k);
-
+				assert(cm);
 				stream->WriteResRef( cm->SpellResRef);
 				stream->WriteDword( &cm->Flags);
 			}
