@@ -27,6 +27,8 @@
 
 #include "Effect.h"
 
+namespace GemRB {
+
 class EFFImporter : public EffectMgr {
 private:
 	DataStream* str;
@@ -36,6 +38,8 @@ private:
 public:
 	EFFImporter(void);
 	~EFFImporter(void);
+	// We need this autoFree, since Effects are included inline
+	// in other file types, without a size header.
 	bool Open(DataStream* stream, bool autoFree = true);
 	Effect* GetEffect(Effect *fx);
 	Effect* GetEffectV1(Effect *fx);
@@ -44,4 +48,6 @@ public:
 };
 
 
+}
+
 #endif
