@@ -27,10 +27,15 @@
 #include "GameData.h"
 #include "Interface.h"
 #include "MapMgr.h"
-#include "System/MemoryStream.h"
+#include "PluginMgr.h"
+#include "TableMgr.h"
+#include "Scriptable/Actor.h"
+#include "System/SlicedStream.h"
 
 #include <cassert>
 
+using namespace GemRB;
+
 #define FAMILIAR_FILL_SIZE 324
 // if your compiler chokes on this, use -1 or 0xff whichever works for you
 #define UNINITIALIZED_CHAR '\xff'
@@ -38,17 +43,19 @@
 GAMImporter::GAMImporter(void)
 {
 	str = NULL;
-	autoFree = false;
+	version = PCSize = PCOffset = PCCount = 0;
+	MazeOffset = NPCOffset = NPCCount = GlobalOffset = GlobalCount = 0;
+	JournalOffset = JournalCount = KillVarsOffset = KillVarsCount = 0;
+	FamiliarsOffset = SavedLocOffset = SavedLocCount = 0;
+	PPLocOffset = PPLocCount = 0;
 }
 
 GAMImporter::~GAMImporter(void)
 {
-	if (str && autoFree) {
-		delete( str );
-	}
+	delete str;
 }
 
-bool GAMImporter::Open(DataStream* stream, bool autoFree)
+bool GAMImporter::Open(DataStream* stream)
 {
 	if (stream == NULL) {
 		return false;
@@ -57,7 +64,6 @@ bool GAMImporter::Open(DataStream* stream, bool autoFree)
 		return false;
 	}
 	str = stream;
-	this->autoFree = autoFree;
 	char Signature[8];
 	str->Read( Signature, 8 );
 	if (strncmp( Signature, "GAMEV0.0", 8 ) == 0) {
@@ -94,7 +100,7 @@ bool GAMImporter::Open(DataStream* stream, bool autoFree)
 			version=GAM_VER_BG;
 		}
 	} else {
-		printMessage( "GAMImporter","This file is not a valid GAM File\n", LIGHT_RED );
+		Log(ERROR, "GAMImporter", "This file is not a valid GAM File");
 		return false;
 	}
 
@@ -132,7 +138,7 @@ Game* GAMImporter::LoadGame(Game *newGame, int ver_override)
 	}
 	str->ReadDword( &newGame->PartyGold );
 	//npc count in party???
-	str->ReadWord( &newGame->NpcInParty );
+	str->ReadWord( &newGame->NpcInParty );  //in ToB this is named 'nPCAreaViewed'
 	str->ReadWord( &newGame->WeatherBits );
 	str->ReadDword( &PCOffset );
 	str->ReadDword( &PCCount );
@@ -145,14 +151,14 @@ Game* GAMImporter::LoadGame(Game *newGame, int ver_override)
 	str->ReadDword( &GlobalOffset );
 	str->ReadDword( &GlobalCount );
 	str->ReadResRef( newGame->CurrentArea );
-	str->ReadDword( &newGame->Unknown48 );//this is still unknown
+	str->ReadDword( &newGame->CurrentLink );//in ToB this is named 'currentLink'
 	str->ReadDword( &JournalCount );
 	str->ReadDword( &JournalOffset );
 	switch (version) {
 		default:
 			MazeOffset = 0;
 			str->ReadDword( &newGame->Reputation );
-			str->ReadResRef( newGame->CurrentArea ); // FIXME: see above
+			str->ReadResRef( newGame->CurrentArea ); // FIXME: this is the 'master area'
 			memcpy(newGame->AnotherArea, newGame->CurrentArea, sizeof(ieResRef) );
 			str->ReadDword( &newGame->ControlStatus );
 			str->ReadDword( &newGame->Expansion );
@@ -319,15 +325,14 @@ Game* GAMImporter::LoadGame(Game *newGame, int ver_override)
 	return newGame;
 }
 
-void SanityCheck(ieWord a,ieWord &b,const char *message)
+static void SanityCheck(ieWord a,ieWord &b,const char *message)
 {
 	if (a==0xffff) {
 		b=0xffff;
 		return;
 	}
 	if (b==0xffff) {
-		printMessage("GAMImporter"," ",LIGHT_RED);
-		printf("Invalid Slot Enabler caught: %s!\n", message);
+		Log(ERROR, "GAMImporter", "Invalid Slot Enabler caught: %s!", message);
 		b=0;
 	}
 }
@@ -393,21 +398,19 @@ Actor* GAMImporter::GetActor(Holder<ActorMgr> aM, bool is_in_party )
 			//quick innates
 			//we spare some memory and time by storing them in the same place
 			//this may be slightly buggy because IWD2 doesn't clear the
-			//fields, but QuickSpellClass is set correctly, problem is
-			//that GemRB doesn't clear QuickSpellClass
+			//fields, but QuickSpellClass is set correctly
 			for (i = 0; i < MAX_QSLOTS; i++) {
 				str->Read( tmp, 8 );
-				if ((tmp[0]!=0) && (pcInfo.QuickSpellResRef[0]==0)) {
+				if ((tmp[0]!=0) && (pcInfo.QuickSpellResRef[i][0]==0)) {
 					memcpy( pcInfo.QuickSpellResRef[i], tmp, 8);
 					//innates
 					pcInfo.QuickSpellClass[i]=0xff;
 				}
 			}
 			//recently discovered fields (bard songs)
-			//str->Seek( 72, GEM_CURRENT_POS);
 			for(i = 0; i<MAX_QSLOTS;i++) {
 				str->Read( tmp, 8 );
-				if ((tmp[0]!=0) && (pcInfo.QuickSpellResRef[0]==0)) {
+				if ((tmp[0]!=0) && (pcInfo.QuickSpellResRef[i][0]==0)) {
 					memcpy( pcInfo.QuickSpellResRef[i], tmp, 8);
 					//bardsongs
 					pcInfo.QuickSpellClass[i]=0xfe;
@@ -468,17 +471,11 @@ Actor* GAMImporter::GetActor(Holder<ActorMgr> aM, bool is_in_party )
 	tmpWord = is_in_party ? (pcInfo.PartyOrder + 1) : 0;
 
 	if (pcInfo.OffsetToCRE) {
-		str->Seek( pcInfo.OffsetToCRE, GEM_STREAM_START );
-		void* Buffer = malloc( pcInfo.CRESize );
-		str->Read( Buffer, pcInfo.CRESize );
-		//somehow autofree MemoryStream doesn't work on msvc 7.0
-		//separate heap for dll's?
-		MemoryStream* ms = new MemoryStream( Buffer, pcInfo.CRESize, false );
+		DataStream* ms = SliceStream( str, pcInfo.OffsetToCRE, pcInfo.CRESize );
 		if (ms) {
-			aM->Open( ms, true );
+			aM->Open(ms);
 			actor = aM->GetActor(tmpWord);
 		}
-		free (Buffer);
 
 		//torment has them as 0 or -1
 		if (pcInfo.Name[0]!=0 && pcInfo.Name[0]!=UNINITIALIZED_CHAR) {
@@ -491,7 +488,7 @@ Actor* GAMImporter::GetActor(Holder<ActorMgr> aM, bool is_in_party )
 		//another plugin cannot free memory stream from this plugin
 		//so auto free is a no-no
 		if (ds) {
-			aM->Open( ds, true );
+			aM->Open(ds);
 			actor = aM->GetActor(pcInfo.PartyOrder);
 		}
 	}
@@ -841,7 +838,7 @@ int GAMImporter::PutHeader(DataStream *stream, Game *game)
 	stream->WriteDword( &GlobalOffset );
 	stream->WriteDword( &GlobalCount );
 	stream->WriteResRef( game->CurrentArea );
-	stream->WriteDword( &game->Unknown48 );
+	stream->WriteDword( &game->CurrentLink );
 	stream->WriteDword( &JournalCount );
 	stream->WriteDword( &JournalOffset );
 
@@ -1020,7 +1017,7 @@ int GAMImporter::PutActor(DataStream *stream, Actor *ac, ieDword CRESize, ieDwor
 	if (ac->LongStrRef==0xffffffff) {
 		strncpy(filling, ac->LongName, 32);
 	} else {
-		char *tmpstr = core->GetString(ac->LongStrRef, IE_STR_STRREFOFF);
+		char *tmpstr = core->GetCString(ac->LongStrRef, IE_STR_STRREFOFF);
 		strncpy(filling, tmpstr, 32);
 		core->FreeString( tmpstr );
 	}
