@@ -25,6 +25,8 @@
 
 #include "ActorMgr.h"
 
+namespace GemRB {
+
 #define GAM_VER_GEMRB  0 
 #define GAM_VER_BG  10   
 #define GAM_VER_IWD 11  
@@ -36,7 +38,6 @@
 class GAMImporter : public SaveGameMgr {
 private:
 	DataStream* str;
-	bool autoFree;
 	int version;
 	unsigned int PCSize;
 	ieDword PCOffset, PCCount;
@@ -51,7 +52,7 @@ private:
 public:
 	GAMImporter(void);
 	~GAMImporter(void);
-	bool Open(DataStream* stream, bool autoFree = true);
+	bool Open(DataStream* stream);
 	Game* LoadGame(Game *newGame, int ver_override = 0);
 
 	int GetStoredFileSize(Game *game);
@@ -80,4 +81,6 @@ private:
 };
 
 #endif
+}
+
 
