@@ -60,7 +60,7 @@ public:
 	/** Exec a single File */
 	void ExecFile(const char* file);
 	/** Exec a single String */
-	void ExecString(const char* string);
+	void ExecString(const char* string, bool feedback=false);
 	/** lets hope this one can be here without screwing up the general interface */
 	PyObject *RunFunction(const char* moduleName, const char* fname, PyObject* pArgs, bool report_error = true);
 	PyObject* ConstructObject(const char* classname, int arg);
