@@ -28,6 +28,8 @@
 #include <cstring>
 #include <vector>
 
+namespace GemRB {
+
 struct INIPair {
 	char* Name, * Value;
 };
@@ -208,4 +210,6 @@ public:
 		const bool Default) const;
 };
 
+}
+
 #endif
