@@ -23,6 +23,8 @@
 
 #include "ImageMgr.h"
 
+namespace GemRB {
+
 class MOSImporter : public ImageMgr {
 private:
 	ieWord Width, Height, Cols, Rows;
@@ -36,4 +38,6 @@ public:
 	int GetHeight() { return (int) Height; }
 };
 
+}
+
 #endif
