@@ -23,6 +23,8 @@
 
 #include "Audio.h"
 
+namespace GemRB {
+
 class NullSound : public Audio {
 public:
 	NullSound(void);
@@ -35,7 +37,6 @@ public:
 	bool Pause();
 	bool Resume();
 	bool CanPlay();
-	bool IsSpeaking();
 	void ResetMusics();
 	void UpdateListenerPos(int XPos, int YPos);
 	void GetListenerPos(int& XPos, int& YPos);
@@ -52,4 +53,6 @@ private:
 	int XPos, YPos;
 };
 
+}
+
 #endif
