@@ -33,6 +33,8 @@
 
 #include <SDL.h>
 
+using namespace GemRB;
+
 // TODO: remove last dependencies on OpenAL, and then rename and move it?
 
 // legal nop if already reset
@@ -65,7 +67,12 @@ void AmbientMgrAL::setAmbients(const std::vector<Ambient *> &a)
 	}
 	core->GetAudioDrv()->UpdateVolume( GEM_SND_VOL_AMBIENTS );
 
+#if	SDL_VERSION_ATLEAST(1, 3, 0)
+	/* as of changeset 3a041d215edc SDL_CreateThread has a 'name' parameter */
+	player = SDL_CreateThread(&play, "AmbientMgrAL", (void *) this);
+#else
 	player = SDL_CreateThread(&play, (void *) this);
+#endif
 }
 
 void AmbientMgrAL::activate(const std::string &name)
@@ -157,6 +164,16 @@ unsigned int AmbientMgrAL::tick(unsigned int ticks)
 	return delay;
 }
 
+void AmbientMgrAL::UpdateVolume(unsigned short volume)
+{
+	SDL_mutexP( mutex );
+	for (std::vector<AmbientSource *>::iterator it = ambientSources.begin(); it != ambientSources.end(); ++it) {
+		(*it) -> SetVolume( volume );
+	}
+	SDL_mutexV( mutex );
+}
+
+
 AmbientMgrAL::AmbientSource::AmbientSource(const Ambient *a)
 : stream(-1), ambient(a), lastticks(0), enqueued(0), loaded(false)
 {
@@ -201,6 +218,7 @@ unsigned int AmbientMgrAL::AmbientSource::tick(unsigned int ticks, Point listene
 		if (stream >= 0) {
 			// release the stream without immediately stopping it
 			core->GetAudioDrv()->ReleaseStream(stream, false);
+			stream = -1;
 		}
 		return UINT_MAX;
 	}
@@ -222,6 +240,7 @@ unsigned int AmbientMgrAL::AmbientSource::tick(unsigned int ticks, Point listene
 		if (delay > 500) {
 			// release stream if we're inactive for a while
 			core->GetAudioDrv()->ReleaseStream(stream);
+			stream = -1;
 		}
 		return delay;
 	}
@@ -231,7 +250,11 @@ unsigned int AmbientMgrAL::AmbientSource::tick(unsigned int ticks, Point listene
 
 	if (stream < 0) {
 		// we need to allocate a stream
-		stream = core->GetAudioDrv()->SetupNewStream(ambient->getOrigin().x, ambient->getOrigin().y, ambient->getHeight(), ambient->getGain(), (ambient->getFlags() & IE_AMBI_POINT), true);
+		unsigned int v = 100;
+
+		core->GetDictionary()->Lookup("Volume Ambients", v);
+		v *= ambient->getGain();
+		stream = core->GetAudioDrv()->SetupNewStream(ambient->getOrigin().x, ambient->getOrigin().y, ambient->getHeight(), v/100, (ambient->getFlags() & IE_AMBI_POINT), true);
 
 		if (stream == -1) {
 			// no streams available...
@@ -269,7 +292,7 @@ int AmbientMgrAL::AmbientSource::enqueue()
 	if (soundrefs.empty()) return -1;
 	if (stream < 0) return -1;
 	int index = rand() % soundrefs.size();
-	//print("Playing ambient %p, %s, %d/%ld on stream %d\n", (void*)this, soundrefs[index], index, soundrefs.size(), stream);
+	//print("Playing ambient %p, %s, %d/%ld on stream %d",(void*)this, soundrefs[index], index, soundrefs.size(), stream);
 	return core->GetAudioDrv()->QueueAmbient(stream, soundrefs[index]);
 }
 
@@ -289,15 +312,6 @@ void AmbientMgrAL::AmbientSource::hardStop()
 	}
 }
 
-void AmbientMgrAL::UpdateVolume(unsigned short volume)
-{
-	SDL_mutexP( mutex );
-	for (std::vector<AmbientSource *>::iterator it = ambientSources.begin(); it != ambientSources.end(); ++it) {
-		(*it) -> SetVolume( volume );
-	}
-	SDL_mutexV( mutex );
-}
-
 /* sets the overall volume (in percent)
  * the final volume is affected by the specific ambient gain
  */
