@@ -32,6 +32,8 @@ WMPImporter::WMPImporter(void)
 {
 	str1 = NULL;
 	str2 = NULL;
+	WorldMapsCount = WorldMapsCount1 = WorldMapsCount2 = 0;
+	WorldMapsOffset1 = WorldMapsOffset2 = 0;
 }
 
 WMPImporter::~WMPImporter(void)
